# ruff: noqa: E501, PLR0915
from __future__ import annotations

types: dict[str, str] = {
    "AMZN::SDC::Deployment": "8366ee98aaa0082b",
    "AWS::ACMPCA::Certificate": "8095f49d3b9d3b1a",
    "AWS::ACMPCA::CertificateAuthority": "97b6ba94b51843fc",
    "AWS::ACMPCA::CertificateAuthorityActivation": "a62fb980b49a2961",
    "AWS::ACMPCA::Permission": "f334231645d9b9b9",
    "AWS::APS::AnomalyDetector": "ce9db55fb4165695",
    "AWS::APS::ResourcePolicy": "da0d17341b025c5d",
    "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
    "AWS::APS::Scraper": "6d167939ca161a78",
    "AWS::APS::Workspace": "0739c3a13c4ccac6",
    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
    "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
    "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
    "AWS::AccessAnalyzer::Analyzer": "f05e81a8f1bcb307",
    "AWS::AmazonMQ::Broker": "c7ad1fe2fbeb2d1b",
    "AWS::AmazonMQ::Configuration": "9a9a64561c801ccb",
    "AWS::AmazonMQ::ConfigurationAssociation": "2343e0ffe1114046",
    "AWS::Amplify::App": "548a8064e4f1406b",
    "AWS::Amplify::Branch": "a695d991e4e66188",
    "AWS::Amplify::Domain": "3fdc7fe1765c72f0",
    "AWS::AmplifyUIBuilder::Component": "2884b0fe64d7b40b",
    "AWS::AmplifyUIBuilder::Form": "a96da0feedd02631",
    "AWS::AmplifyUIBuilder::Theme": "da398fd14d8f536a",
    "AWS::ApiGateway::Account": "1876f63604439391",
    "AWS::ApiGateway::ApiKey": "48205d4ffd7feba3",
    "AWS::ApiGateway::Authorizer": "a51c1c1fc1195550",
    "AWS::ApiGateway::BasePathMapping": "14bcf4ff90345f78",
    "AWS::ApiGateway::BasePathMappingV2": "361e364ef63cf6fd",
    "AWS::ApiGateway::ClientCertificate": "3c72d768c43d41a3",
    "AWS::ApiGateway::Deployment": "2ffb8f3345f190c2",
    "AWS::ApiGateway::DocumentationPart": "1383fef137de858b",
    "AWS::ApiGateway::DocumentationVersion": "8f19f440f5e47b9f",
    "AWS::ApiGateway::DomainName": "1b67859ef84a0247",
    "AWS::ApiGateway::DomainNameAccessAssociation": "a990644bdd54299e",
    "AWS::ApiGateway::DomainNameV2": "a0369b9dd79fc7c8",
    "AWS::ApiGateway::GatewayResponse": "43d430f7d4055e59",
    "AWS::ApiGateway::Method": "8d3568941b9c1cfe",
    "AWS::ApiGateway::Model": "80f210a42639b333",
    "AWS::ApiGateway::RequestValidator": "afc1110de614be93",
    "AWS::ApiGateway::Resource": "0b20e16c9c975c0d",
    "AWS::ApiGateway::RestApi": "7c13875334b62e8c",
    "AWS::ApiGateway::Stage": "56ecb180a441ee32",
    "AWS::ApiGateway::UsagePlan": "c9548a0a281386e5",
    "AWS::ApiGateway::UsagePlanKey": "309b26469128fd0a",
    "AWS::ApiGateway::VpcLink": "3c3c844926fba248",
    "AWS::ApiGatewayV2::Api": "fdc84407d8d6260e",
    "AWS::ApiGatewayV2::ApiGatewayManagedOverrides": "6852b176617879b0",
    "AWS::ApiGatewayV2::ApiMapping": "907de0790553e448",
    "AWS::ApiGatewayV2::Authorizer": "69107e1e01673765",
    "AWS::ApiGatewayV2::Deployment": "81174b55f308dad3",
    "AWS::ApiGatewayV2::DomainName": "87535a11b8340a18",
    "AWS::ApiGatewayV2::Integration": "77743451e77a7545",
    "AWS::ApiGatewayV2::IntegrationResponse": "a319db9e828555fa",
    "AWS::ApiGatewayV2::Model": "fcc09a7d8ffbd09c",
    "AWS::ApiGatewayV2::Route": "112b036b7d923f13",
    "AWS::ApiGatewayV2::RouteResponse": "3606f855415b8421",
    "AWS::ApiGatewayV2::RoutingRule": "b9e023c3c57c3c04",
    "AWS::ApiGatewayV2::Stage": "2903f59facc01e1c",
    "AWS::ApiGatewayV2::VpcLink": "e5ea6845d4e71e0b",
    "AWS::AppConfig::Application": "b607b28b7e719446",
    "AWS::AppConfig::ConfigurationProfile": "cf14987e3f150eb8",
    "AWS::AppConfig::Deployment": "a999b7bdf5b07cf5",
    "AWS::AppConfig::DeploymentStrategy": "e6d16ca1a1cd4c61",
    "AWS::AppConfig::Environment": "0c307beb222c782d",
    "AWS::AppConfig::Extension": "d798510534a27baf",
    "AWS::AppConfig::ExtensionAssociation": "85102348a3d001d3",
    "AWS::AppConfig::HostedConfigurationVersion": "4d2f292068fae1c6",
    "AWS::AppFlow::Connector": "56d626939778ba2f",
    "AWS::AppFlow::ConnectorProfile": "bb0dcbf5a4f0802f",
    "AWS::AppFlow::Flow": "d32ee28f72947041",
    "AWS::AppIntegrations::Application": "014e7664ce5a1a86",
    "AWS::AppIntegrations::DataIntegration": "9c903668eae3b7b1",
    "AWS::AppIntegrations::EventIntegration": "3713bfde8fafbe46",
    "AWS::AppMesh::GatewayRoute": "f31fd0c34cd762b9",
    "AWS::AppMesh::Mesh": "375120e4ddc54cb5",
    "AWS::AppMesh::Route": "10f96fe755a3b866",
    "AWS::AppMesh::VirtualGateway": "ea8db60d40f51bd0",
    "AWS::AppMesh::VirtualNode": "bda61df49b15dd6b",
    "AWS::AppMesh::VirtualRouter": "1a8079d7b7fd931b",
    "AWS::AppMesh::VirtualService": "b6b6bd277d3b2302",
    "AWS::AppStream::AppBlock": "60a3a9b8f43b3525",
    "AWS::AppStream::AppBlockBuilder": "3087e48685697649",
    "AWS::AppStream::Application": "357f39e2d6b0b31d",
    "AWS::AppStream::ApplicationEntitlementAssociation": "35e176c811a25063",
    "AWS::AppStream::ApplicationFleetAssociation": "93b71c4884fff935",
    "AWS::AppStream::DirectoryConfig": "d5a3c7fb900c1e1b",
    "AWS::AppStream::Entitlement": "541a9ea2c6b359ec",
    "AWS::AppStream::Fleet": "eda4ed21dac3c49e",
    "AWS::AppStream::ImageBuilder": "c60b70bcc244a5aa",
    "AWS::AppStream::Stack": "4553c486067dd5c8",
    "AWS::AppStream::StackFleetAssociation": "b02fcd7c6e463b45",
    "AWS::AppStream::StackUserAssociation": "60d6d43aff078611",
    "AWS::AppStream::User": "ee1b36cca0fd339c",
    "AWS::AppSync::Api": "b46594583c264d17",
    "AWS::AppSync::ApiCache": "d7a7fb82edccdfe2",
    "AWS::AppSync::ApiKey": "3d104ea0be48564b",
    "AWS::AppSync::ChannelNamespace": "194048f8c8383a17",
    "AWS::AppSync::DataSource": "f42f0eade43578bb",
    "AWS::AppSync::DomainName": "90cf6b5b0582fe8c",
    "AWS::AppSync::DomainNameApiAssociation": "d4af4b8aef39897a",
    "AWS::AppSync::FunctionConfiguration": "002d7fdacf417d21",
    "AWS::AppSync::GraphQLApi": "2d5221ec6cdad6fe",
    "AWS::AppSync::GraphQLSchema": "b3409083f48d1b5b",
    "AWS::AppSync::Resolver": "81052e564e6d42f5",
    "AWS::AppSync::SourceApiAssociation": "8176278e728ac6a7",
    "AWS::ApplicationAutoScaling::ScalableTarget": "de001f7e2b117e91",
    "AWS::ApplicationAutoScaling::ScalingPolicy": "a86b9b958db4147e",
    "AWS::ApplicationInsights::Application": "4fb681541bc69d81",
    "AWS::ApplicationSignals::Discovery": "2bbcdf020ea7fc15",
    "AWS::ApplicationSignals::GroupingConfiguration": "e9154cde60fc6255",
    "AWS::ApplicationSignals::ServiceLevelObjective": "148bbf048d668735",
    "AWS::Athena::DataCatalog": "72b7e9ce721875ee",
    "AWS::Athena::NamedQuery": "8adbac6f36c9aa6b",
    "AWS::Athena::PreparedStatement": "f136b10278378b55",
    "AWS::Athena::WorkGroup": "98125aa523006e5f",
    "AWS::AutoScaling::AutoScalingGroup": "05a01deca7473008",
    "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
    "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
    "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
    "AWS::AutoScaling::ScheduledAction": "ab00e084f1d921e6",
    "AWS::AutoScaling::WarmPool": "93498a4faffea6ae",
    "AWS::AutoScalingPlans::ScalingPlan": "81df3d07362fff07",
    "AWS::Backup::BackupPlan": "320b6510a85d684e",
    "AWS::Backup::BackupSelection": "26040166156c899a",
    "AWS::Backup::BackupVault": "695e80a4aaec9275",
    "AWS::Backup::Framework": "df47da6f2d6712da",
    "AWS::Backup::LogicallyAirGappedBackupVault": "99976d61395f41e3",
    "AWS::Backup::ReportPlan": "ac5222585ea4fb04",
    "AWS::Backup::RestoreTestingPlan": "a1fd4f431c67c9f4",
    "AWS::Backup::RestoreTestingSelection": "d4f6fc7c7d230fb2",
    "AWS::BackupGateway::Hypervisor": "cd1de2c6ed11afdd",
    "AWS::Batch::ComputeEnvironment": "c04685284080736b",
    "AWS::Batch::ConsumableResource": "8e12226640545a9a",
    "AWS::Batch::JobDefinition": "8a7ecae4430d86b2",
    "AWS::Batch::JobQueue": "330cfa7e67eefadc",
    "AWS::Batch::SchedulingPolicy": "06201d728045e9e4",
    "AWS::Batch::ServiceEnvironment": "72c42b7d08edd4dc",
    "AWS::Bedrock::Agent": "bde4b07f1c4b6973",
    "AWS::Bedrock::AgentAlias": "957e2ce5a7007785",
    "AWS::Bedrock::ApplicationInferenceProfile": "4cfe04077b4d87f2",
    "AWS::Bedrock::DataSource": "9ca916388ec8b805",
    "AWS::Bedrock::Flow": "7d800d89c886b72c",
    "AWS::Bedrock::FlowAlias": "36fa0dff459bcfd0",
    "AWS::Bedrock::FlowVersion": "3f011854b48e4c5b",
    "AWS::Bedrock::Guardrail": "2cb3f0e888718dad",
    "AWS::Bedrock::GuardrailVersion": "5bf27647412382c4",
    "AWS::Bedrock::IntelligentPromptRouter": "040f7d0235bb7200",
    "AWS::Bedrock::KnowledgeBase": "42afb318cede00fc",
    "AWS::Bedrock::Prompt": "63cb5b7f989bfc36",
    "AWS::Bedrock::PromptVersion": "41e3e79078ba156a",
    "AWS::BedrockAgentCore::Gateway": "a629441d622699ce",
    "AWS::BedrockAgentCore::GatewayTarget": "f190da008ea2a70a",
    "AWS::BedrockAgentCore::WorkloadIdentity": "78d4c036021cc12e",
    "AWS::Budgets::Budget": "ebac0f729cbbf76a",
    "AWS::Budgets::BudgetsAction": "e06dd2791075c9d6",
    "AWS::CDK::Metadata": "6c85ec990b9ac854",
    "AWS::CE::AnomalyMonitor": "3238fa7e318e3af7",
    "AWS::CE::AnomalySubscription": "5c01c255f3f4980b",
    "AWS::CE::CostCategory": "0ca417b146507094",
    "AWS::Cases::CaseRule": "3c901a066e2031a8",
    "AWS::Cases::Domain": "819687c312320180",
    "AWS::Cases::Field": "575dad6f219c55da",
    "AWS::Cases::Layout": "f48d9c43985a0937",
    "AWS::Cases::Template": "af733164010ae401",
    "AWS::Cassandra::Keyspace": "0bd2067860b304f2",
    "AWS::Cassandra::Table": "cb4f8b935e3eae9c",
    "AWS::Cassandra::Type": "8aec046f867c1dce",
    "AWS::CertificateManager::Account": "403ae9aaf56cf1a4",
    "AWS::CertificateManager::Certificate": "169f6d71dc51fcc8",
    "AWS::Chatbot::CustomAction": "f8ad09ff43d3bb61",
    "AWS::Chatbot::MicrosoftTeamsChannelConfiguration": "010fe053ff4053d8",
    "AWS::Chatbot::SlackChannelConfiguration": "733a3e7b4bdf0053",
    "AWS::CleanRooms::AnalysisTemplate": "fa83ca65f4bbb876",
    "AWS::CleanRooms::Collaboration": "fa1593af917ba247",
    "AWS::CleanRooms::ConfiguredTable": "2e7f2a7ba2926d27",
    "AWS::CleanRooms::ConfiguredTableAssociation": "2d7fbce0930cc73d",
    "AWS::CleanRooms::IdMappingTable": "2a5b2698a99d13ae",
    "AWS::CleanRooms::IdNamespaceAssociation": "237126ad95e8f1d5",
    "AWS::CleanRooms::Membership": "39410c6e94c1968c",
    "AWS::CleanRooms::PrivacyBudgetTemplate": "da2433f8e8f3ca7d",
    "AWS::CleanRoomsML::TrainingDataset": "a5364e138c2bcad5",
    "AWS::Cloud9::EnvironmentEC2": "499b5671efc4029e",
    "AWS::CloudFormation::CustomResource": "e1f552bc7275a696",
    "AWS::CloudFormation::GuardHook": "a48f290f69a60c20",
    "AWS::CloudFormation::HookDefaultVersion": "ed13bf5a5bcf4773",
    "AWS::CloudFormation::HookTypeConfig": "8dac7817ef160a80",
    "AWS::CloudFormation::HookVersion": "8ddaf92d4ae6b0da",
    "AWS::CloudFormation::LambdaHook": "8e773b451512bd0f",
    "AWS::CloudFormation::Macro": "8517053591f9eceb",
    "AWS::CloudFormation::ModuleDefaultVersion": "0b395493be154f0d",
    "AWS::CloudFormation::ModuleVersion": "f98c4b774da7cc16",
    "AWS::CloudFormation::PublicTypeVersion": "e68574e847dfa548",
    "AWS::CloudFormation::Publisher": "03c41096bbdb2ba7",
    "AWS::CloudFormation::ResourceDefaultVersion": "f614137749ff39d3",
    "AWS::CloudFormation::ResourceVersion": "cb8c2d939b790590",
    "AWS::CloudFormation::Stack": "089169583d0e826d",
    "AWS::CloudFormation::StackSet": "bf26be80cf86dbfd",
    "AWS::CloudFormation::TypeActivation": "6e3bec3534fc9f42",
    "AWS::CloudFormation::WaitCondition": "e62c75075457f02f",
    "AWS::CloudFormation::WaitConditionHandle": "edba290fd70976a3",
    "AWS::CloudFront::AnycastIpList": "beb2df4a9b037d07",
    "AWS::CloudFront::CachePolicy": "53d9f632b7e1d5b7",
    "AWS::CloudFront::CloudFrontOriginAccessIdentity": "d2e8d397beac5797",
    "AWS::CloudFront::ConnectionFunction": "d78bd117dcdb2119",
    "AWS::CloudFront::ConnectionGroup": "68ca2c6e67355a40",
    "AWS::CloudFront::ContinuousDeploymentPolicy": "bf0fd1f8e692b34d",
    "AWS::CloudFront::Distribution": "23e0328c26fb5ba6",
    "AWS::CloudFront::DistributionTenant": "0645b8023b061e15",
    "AWS::CloudFront::Function": "f3bfd8485e232a78",
    "AWS::CloudFront::KeyGroup": "7a9f609d809f1f8e",
    "AWS::CloudFront::KeyValueStore": "674d07fa20c06be2",
    "AWS::CloudFront::MonitoringSubscription": "f9dae15a96e422a7",
    "AWS::CloudFront::OriginAccessControl": "17f386694e5709fe",
    "AWS::CloudFront::OriginRequestPolicy": "97711158d1bc4353",
    "AWS::CloudFront::PublicKey": "b5cac84e7e953094",
    "AWS::CloudFront::RealtimeLogConfig": "94564597650a9bf8",
    "AWS::CloudFront::ResponseHeadersPolicy": "d5eaaa7cf7b104dc",
    "AWS::CloudFront::StreamingDistribution": "06c74c3c98bc5def",
    "AWS::CloudFront::TrustStore": "92e85e94558a980f",
    "AWS::CloudFront::VpcOrigin": "eed344f918658fdd",
    "AWS::CloudTrail::Channel": "2a73bf4b08d2d1a1",
    "AWS::CloudTrail::Dashboard": "28e73ef34409d386",
    "AWS::CloudTrail::EventDataStore": "0f62715e88eb3a3a",
    "AWS::CloudTrail::ResourcePolicy": "ab2ae9ccbbd62450",
    "AWS::CloudTrail::Trail": "7fca39d8e460aae0",
    "AWS::CloudWatch::Alarm": "c5552fedb35a08eb",
    "AWS::CloudWatch::AnomalyDetector": "13b8b743191bf50f",
    "AWS::CloudWatch::CompositeAlarm": "5c9a218af0588cb5",
    "AWS::CloudWatch::Dashboard": "423086b5b02bd126",
    "AWS::CloudWatch::InsightRule": "7b287284e7e98391",
    "AWS::CloudWatch::MetricStream": "7428a359e19d26c0",
    "AWS::CodeBuild::Project": "cabfc6f21a839ae8",
    "AWS::CodeBuild::ReportGroup": "b34ce85ee1e4a8da",
    "AWS::CodeBuild::SourceCredential": "b84e190d9ebbbfe1",
    "AWS::CodeCommit::Repository": "70fff8b988e25027",
    "AWS::CodeConnections::Connection": "c5a1edd34dbcaa17",
    "AWS::CodeDeploy::Application": "eea8100bd279b205",
    "AWS::CodeDeploy::DeploymentConfig": "394f39ae21382747",
    "AWS::CodeDeploy::DeploymentGroup": "36c8d71f30ed60e4",
    "AWS::CodePipeline::CustomActionType": "726ad61840645aa5",
    "AWS::CodePipeline::Pipeline": "580b88b2161ff941",
    "AWS::CodePipeline::Webhook": "a6ad2a4dc85ed032",
    "AWS::CodeStar::GitHubRepository": "eaeb2974516b47e3",
    "AWS::CodeStarConnections::Connection": "6b8c8b99af488ddd",
    "AWS::CodeStarConnections::RepositoryLink": "aeaea7367d7cf5bf",
    "AWS::CodeStarConnections::SyncConfiguration": "07937eff6fca823f",
    "AWS::CodeStarNotifications::NotificationRule": "3eec2cf7fa62e88b",
    "AWS::Cognito::IdentityPool": "3df22057c8e2ef54",
    "AWS::Cognito::IdentityPoolPrincipalTag": "3ae793569104c4f6",
    "AWS::Cognito::IdentityPoolRoleAttachment": "2a5296f4ca5a2ff7",
    "AWS::Cognito::LogDeliveryConfiguration": "2e1fa665bc591a0b",
    "AWS::Cognito::ManagedLoginBranding": "5c891e6d32f0ba8d",
    "AWS::Cognito::Terms": "f5bf1f3a97d979ba",
    "AWS::Cognito::UserPool": "4294848dd5d358d2",
    "AWS::Cognito::UserPoolClient": "56f070dbecb283f1",
    "AWS::Cognito::UserPoolDomain": "b89172fa4b1cf22a",
    "AWS::Cognito::UserPoolGroup": "a7315a389c858da9",
    "AWS::Cognito::UserPoolIdentityProvider": "497642110bee02ad",
    "AWS::Cognito::UserPoolResourceServer": "89ba39a21f9326df",
    "AWS::Cognito::UserPoolRiskConfigurationAttachment": "650fce2645198ef2",
    "AWS::Cognito::UserPoolUICustomizationAttachment": "9a793e05ae357b1c",
    "AWS::Cognito::UserPoolUser": "b71b230dcbe501c3",
    "AWS::Cognito::UserPoolUserToGroupAttachment": "642c498727b1c8f4",
    "AWS::Comprehend::DocumentClassifier": "5ac6bae182a45527",
    "AWS::Comprehend::Flywheel": "0934cbd2ad7fe4c3",
    "AWS::Config::AggregationAuthorization": "8957a0832482c5e3",
    "AWS::Config::ConfigRule": "161d23fa95d2540a",
    "AWS::Config::ConfigurationAggregator": "6192663bb376a59c",
    "AWS::Config::ConfigurationRecorder": "e35cee148e38b939",
    "AWS::Config::ConformancePack": "efd1c65408fe7667",
    "AWS::Config::DeliveryChannel": "4f7af4ff91e52582",
    "AWS::Config::OrganizationConfigRule": "1f49966ab4677d68",
    "AWS::Config::OrganizationConformancePack": "d54c4d30bffad2b7",
    "AWS::Config::RemediationConfiguration": "1891f5fc168dbf44",
    "AWS::Config::StoredQuery": "c02d3b47f92dac62",
    "AWS::Connect::AgentStatus": "e4d33392ae941342",
    "AWS::Connect::ApprovedOrigin": "9d9f12f666c7d568",
    "AWS::Connect::ContactFlow": "e7ed1215a325612c",
    "AWS::Connect::ContactFlowModule": "8fa9fa9b46d0415e",
    "AWS::Connect::DataTable": "18cd7792603e69c5",
    "AWS::Connect::DataTableAttribute": "08713b122feb23e4",
    "AWS::Connect::DataTableRecord": "db6c4d160c0da36f",
    "AWS::Connect::EmailAddress": "807b7160b3385afb",
    "AWS::Connect::EvaluationForm": "d4ec84ca94cd03eb",
    "AWS::Connect::HoursOfOperation": "0ad5f5246de080b7",
    "AWS::Connect::Instance": "818f2e8da01f29d9",
    "AWS::Connect::InstanceStorageConfig": "036e51d554e029ec",
    "AWS::Connect::IntegrationAssociation": "05d606eba9d7fcad",
    "AWS::Connect::PhoneNumber": "7b74782f8b375eb5",
    "AWS::Connect::PredefinedAttribute": "b463662166d96c93",
    "AWS::Connect::Prompt": "dacb9a25a3900260",
    "AWS::Connect::Queue": "24b3619c8817d80c",
    "AWS::Connect::QuickConnect": "a1eaf3a9d25d7620",
    "AWS::Connect::RoutingProfile": "fdb02c4cceaed889",
    "AWS::Connect::Rule": "a1bc460a7ddb424f",
    "AWS::Connect::SecurityKey": "e9f93d5d01b7cd8a",
    "AWS::Connect::SecurityProfile": "c9c4f736d5dba585",
    "AWS::Connect::TaskTemplate": "d2256ce85b613ac8",
    "AWS::Connect::User": "5a64b3c240666284",
    "AWS::Connect::UserHierarchyGroup": "7cf5994e34fb0eee",
    "AWS::Connect::UserHierarchyStructure": "69430fd905006f57",
    "AWS::Connect::View": "7ae82e4e602a5391",
    "AWS::Connect::ViewVersion": "ea786d1508fd84c3",
    "AWS::Connect::Workspace": "5bdb7137bb104782",
    "AWS::ConnectCampaignsV2::Campaign": "8b4c5c0703a330bd",
    "AWS::ControlTower::EnabledBaseline": "fc45dfb83aa6dd82",
    "AWS::ControlTower::EnabledControl": "ac0e492fde8853d9",
    "AWS::ControlTower::LandingZone": "96c88ada196eeb0e",
    "AWS::CustomerProfiles::CalculatedAttributeDefinition": "81da3130233325a0",
    "AWS::CustomerProfiles::Domain": "aa830cf9368f9f97",
    "AWS::CustomerProfiles::EventStream": "3f1d9d2ece69a5a6",
    "AWS::CustomerProfiles::EventTrigger": "433ae33b7ce88aca",
    "AWS::CustomerProfiles::Integration": "cc301ddea32cd660",
    "AWS::CustomerProfiles::ObjectType": "7383e179a19477e1",
    "AWS::CustomerProfiles::SegmentDefinition": "bbf4c096c2334b52",
    "AWS::DLM::LifecyclePolicy": "0287ea6dffbb40a2",
    "AWS::DMS::Certificate": "89efe57b4144e9ab",
    "AWS::DMS::DataMigration": "ade967581e1dfc34",
    "AWS::DMS::DataProvider": "94c68c86840900fc",
    "AWS::DMS::Endpoint": "945bb565b81d0034",
    "AWS::DMS::EventSubscription": "fdd5de7c61bc5946",
    "AWS::DMS::InstanceProfile": "b289107706553b44",
    "AWS::DMS::MigrationProject": "b4b035d4b0f0b861",
    "AWS::DMS::ReplicationConfig": "563e9b573376b7ec",
    "AWS::DMS::ReplicationInstance": "e491c749b1a4069d",
    "AWS::DMS::ReplicationSubnetGroup": "38c929d04f7ce1ee",
    "AWS::DMS::ReplicationTask": "0b9ef1a765b40e51",
    "AWS::DSQL::Cluster": "a95a23c20c0a2c87",
    "AWS::DataBrew::Dataset": "d3b92e5e742770a5",
    "AWS::DataBrew::Job": "c8448544ff8acc4b",
    "AWS::DataBrew::Project": "f5afe30316bff351",
    "AWS::DataBrew::Recipe": "6fa6e2d8322ea926",
    "AWS::DataBrew::Ruleset": "932632c822ce6169",
    "AWS::DataBrew::Schedule": "1995bc021a9e7e23",
    "AWS::DataPipeline::Pipeline": "f54867769cc566cf",
    "AWS::DataSync::Agent": "5f41806ea8ec42b9",
    "AWS::DataSync::LocationAzureBlob": "d8a83e58123bc26d",
    "AWS::DataSync::LocationEFS": "f74b4ff1503e9407",
    "AWS::DataSync::LocationFSxLustre": "bf64014c70578e21",
    "AWS::DataSync::LocationFSxONTAP": "f120a7ad0e329aaf",
    "AWS::DataSync::LocationFSxOpenZFS": "542f58e4d98fb8cf",
    "AWS::DataSync::LocationFSxWindows": "4fa3850617966c77",
    "AWS::DataSync::LocationHDFS": "0639306ca013b8ec",
    "AWS::DataSync::LocationNFS": "2659197742246dcd",
    "AWS::DataSync::LocationObjectStorage": "a66b77a26a3e1747",
    "AWS::DataSync::LocationS3": "0190e1a20831d5e0",
    "AWS::DataSync::LocationSMB": "84f56a8c81ace8fd",
    "AWS::DataSync::Task": "d896b335ffc11f10",
    "AWS::DataZone::Connection": "36206200921236e5",
    "AWS::DataZone::DataSource": "5522a6a5cd1e1a3e",
    "AWS::DataZone::Domain": "a73fade42476d81b",
    "AWS::DataZone::DomainUnit": "711f0c6aabf717bd",
    "AWS::DataZone::Environment": "90d9cbf3a3ed746b",
    "AWS::DataZone::EnvironmentActions": "74f98b0cb8b35451",
    "AWS::DataZone::EnvironmentBlueprintConfiguration": "2eaef7d5eed54c20",
    "AWS::DataZone::EnvironmentProfile": "e0cb32e5d86cbc08",
    "AWS::DataZone::FormType": "c4cdf1e5e0a284ed",
    "AWS::DataZone::GroupProfile": "74ae2ae09d16d68e",
    "AWS::DataZone::Owner": "0aeb22658fe8e650",
    "AWS::DataZone::PolicyGrant": "4a122be9c506c908",
    "AWS::DataZone::Project": "2f7d1fc808f3eed8",
    "AWS::DataZone::ProjectMembership": "9afaeb6b2c0a7ad8",
    "AWS::DataZone::ProjectProfile": "069e12fef6b972f5",
    "AWS::DataZone::SubscriptionTarget": "ed731ffbd196f802",
    "AWS::DataZone::UserProfile": "db3a5863b7d055bd",
    "AWS::Deadline::Farm": "c9bbcca2240de1e6",
    "AWS::Deadline::Fleet": "b90dfd2bd6566e09",
    "AWS::Deadline::LicenseEndpoint": "a7360cf2545e5655",
    "AWS::Deadline::Limit": "9e9f7849ca105770",
    "AWS::Deadline::MeteredProduct": "8328238a305e3103",
    "AWS::Deadline::Monitor": "38579f0b8ed92e98",
    "AWS::Deadline::Queue": "0dbdd63e530b8aa2",
    "AWS::Deadline::QueueEnvironment": "a4eec64f73cc9ea5",
    "AWS::Deadline::QueueFleetAssociation": "2f031231c56ebc67",
    "AWS::Deadline::QueueLimitAssociation": "aeada8be70f1b716",
    "AWS::Deadline::StorageProfile": "f9b24e7bca3abb05",
    "AWS::Detective::Graph": "dbed0b7e7b29e1e6",
    "AWS::Detective::MemberInvitation": "86355f574dcf77f5",
    "AWS::Detective::OrganizationAdmin": "28db50ef7caf9609",
    "AWS::DevOpsGuru::LogAnomalyDetectionIntegration": "c82fe28dc7521465",
    "AWS::DevOpsGuru::NotificationChannel": "2d809460f09a7b45",
    "AWS::DevOpsGuru::ResourceCollection": "d6cf75b9cf367649",
    "AWS::DirectoryService::MicrosoftAD": "b23e6a2f55331f07",
    "AWS::DirectoryService::SimpleAD": "ac553e5bf250acca",
    "AWS::DocDB::DBCluster": "be6f39b91c56eff9",
    "AWS::DocDB::DBClusterParameterGroup": "b5e79e7b15b26143",
    "AWS::DocDB::DBInstance": "253562f270b587ac",
    "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
    "AWS::DocDB::EventSubscription": "d22815028d03f301",
    "AWS::DocDB::GlobalCluster": "8a43a2ee7a595e9a",
    "AWS::DocDBElastic::Cluster": "5686e00f54e9aae6",
    "AWS::DynamoDB::GlobalTable": "bfb73ef91cc656d2",
    "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
    "AWS::EC2::CapacityManagerDataExport": "eadbbd5d7fd8fd3c",
    "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
    "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
    "AWS::EC2::CarrierGateway": "ac1f397e6adda506",
    "AWS::EC2::ClientVpnAuthorizationRule": "9dfbd181c3c5a54c",
    "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
    "AWS::EC2::ClientVpnRoute": "f1d130776f4e1473",
    "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
    "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
    "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
    "AWS::EC2::EC2Fleet": "46456be2fbbfb010",
    "AWS::EC2::EIP": "cc42df82cdc81e9c",
    "AWS::EC2::EIPAssociation": "a267820d6250f189",
    "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
    "AWS::EC2::EnclaveCertificateIamRoleAssociation": "d2373cb299cb1831",
    "AWS::EC2::FlowLog": "ea553ae6f4a71ce3",
    "AWS::EC2::GatewayRouteTableAssociation": "50b450990964d2e7",
    "AWS::EC2::Host": "ba21ffd03e701456",
    "AWS::EC2::IPAM": "6fc9a0643e75121d",
    "AWS::EC2::IPAMAllocation": "c4cba824ca02ce4f",
    "AWS::EC2::IPAMPool": "0509442cdc1e18b1",
    "AWS::EC2::IPAMPoolCidr": "873e7cc6e6afef96",
    "AWS::EC2::IPAMResourceDiscovery": "694c0afb626c30d8",
    "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
    "AWS::EC2::IPAMScope": "f1341090e0e57749",
    "AWS::EC2::Instance": "a922ff4a1cb10687",
    "AWS::EC2::InstanceConnectEndpoint": "aff65ea38d1b25dc",
    "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
    "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
    "AWS::EC2::KeyPair": "349deb28f79434e4",
    "AWS::EC2::LaunchTemplate": "2da58e06d7524dc5",
    "AWS::EC2::LocalGatewayRoute": "b50d8737e0b1ea90",
    "AWS::EC2::LocalGatewayRouteTable": "6892bdd3f1f99df6",
    "AWS::EC2::LocalGatewayRouteTableVPCAssociation": "b1d6ce946dcb69b8",
    "AWS::EC2::LocalGatewayRouteTableVirtualInterfaceGroupAssociation": "632889615ea7dc14",
    "AWS::EC2::LocalGatewayVirtualInterface": "157dfe2a5a961bb9",
    "AWS::EC2::LocalGatewayVirtualInterfaceGroup": "1ed30b89e3e9b7ed",
    "AWS::EC2::NatGateway": "28e80cb1fcf92145",
    "AWS::EC2::NetworkAcl": "41c7ec1cea436cd8",
    "AWS::EC2::NetworkAclEntry": "d4fc9ce8669023f0",
    "AWS::EC2::NetworkInsightsAccessScope": "f174ef9549ba3fd9",
    "AWS::EC2::NetworkInsightsAccessScopeAnalysis": "d9d932b88ae8cef7",
    "AWS::EC2::NetworkInsightsAnalysis": "594bd95d5c037217",
    "AWS::EC2::NetworkInsightsPath": "25418106de92f812",
    "AWS::EC2::NetworkInterface": "1e436db5d46542c6",
    "AWS::EC2::NetworkInterfaceAttachment": "0d96c6d7269bdfb0",
    "AWS::EC2::NetworkInterfacePermission": "ff24405331f855c9",
    "AWS::EC2::NetworkPerformanceMetricSubscription": "a507c085bf7ffbcf",
    "AWS::EC2::PlacementGroup": "8dca9ce7eb8b50ac",
    "AWS::EC2::PrefixList": "c53292c8686d14de",
    "AWS::EC2::Route": "0ff811157612151a",
    "AWS::EC2::RouteServer": "f53338d8b3c6499a",
    "AWS::EC2::RouteServerAssociation": "22bb952c9a61f2a9",
    "AWS::EC2::RouteServerEndpoint": "40a2b7461aa985fa",
    "AWS::EC2::RouteServerPeer": "0b52f45b8ea8cbac",
    "AWS::EC2::RouteServerPropagation": "0dd3a42d71c85b11",
    "AWS::EC2::RouteTable": "67bdbfcad069c66a",
    "AWS::EC2::SecurityGroup": "5390282384be7866",
    "AWS::EC2::SecurityGroupEgress": "840df778de9b4be2",
    "AWS::EC2::SecurityGroupIngress": "367136b2f03f428c",
    "AWS::EC2::SecurityGroupVpcAssociation": "f48680388ee894fe",
    "AWS::EC2::SnapshotBlockPublicAccess": "f6434397a8c7e382",
    "AWS::EC2::SpotFleet": "b3c6b5b2f4a5b7d2",
    "AWS::EC2::Subnet": "a60b8dc0c7f50396",
    "AWS::EC2::SubnetCidrBlock": "473785ce782ba18f",
    "AWS::EC2::SubnetNetworkAclAssociation": "6b4f4042734e67b7",
    "AWS::EC2::SubnetRouteTableAssociation": "6b18db45c4ef5f57",
    "AWS::EC2::TrafficMirrorFilter": "d97085902d4e54ae",
    "AWS::EC2::TrafficMirrorFilterRule": "df0dc3904abb859c",
    "AWS::EC2::TrafficMirrorSession": "ec54e16ff79eaac0",
    "AWS::EC2::TrafficMirrorTarget": "562f502a60abccd6",
    "AWS::EC2::TransitGateway": "bdd0278ecaccd4ae",
    "AWS::EC2::TransitGatewayAttachment": "40111e00bf0df74a",
    "AWS::EC2::TransitGatewayConnect": "05caf42b9c40a843",
    "AWS::EC2::TransitGatewayConnectPeer": "27459a628d254042",
    "AWS::EC2::TransitGatewayMeteringPolicy": "4daf1939996f77df",
    "AWS::EC2::TransitGatewayMeteringPolicyEntry": "153b7c0d6fcca798",
    "AWS::EC2::TransitGatewayMulticastDomain": "8a9fdc16690320b7",
    "AWS::EC2::TransitGatewayMulticastDomainAssociation": "f650430e0bbdcce9",
    "AWS::EC2::TransitGatewayMulticastGroupMember": "fe8c827e156dc451",
    "AWS::EC2::TransitGatewayMulticastGroupSource": "95b20156fbc77eb0",
    "AWS::EC2::TransitGatewayPeeringAttachment": "2a33a8efb207e5e5",
    "AWS::EC2::TransitGatewayRoute": "41a8efed021fd377",
    "AWS::EC2::TransitGatewayRouteTable": "46974e4ed5fe86b7",
    "AWS::EC2::TransitGatewayRouteTableAssociation": "a28bde73d4a5cde6",
    "AWS::EC2::TransitGatewayRouteTablePropagation": "e21e0c3273d49afe",
    "AWS::EC2::TransitGatewayVpcAttachment": "9f86e47a59b89462",
    "AWS::EC2::VPC": "f08626e9e82df64f",
    "AWS::EC2::VPCBlockPublicAccessExclusion": "27a1b09ed6dc90f2",
    "AWS::EC2::VPCBlockPublicAccessOptions": "1227e027d1c429f9",
    "AWS::EC2::VPCCidrBlock": "2ab876850f9f6c40",
    "AWS::EC2::VPCDHCPOptionsAssociation": "f803bdbad7d930d1",
    "AWS::EC2::VPCEndpoint": "1ece9f120d9da74a",
    "AWS::EC2::VPCEndpointConnectionNotification": "4d7f63de5d4c3a2e",
    "AWS::EC2::VPCEndpointService": "150eafe6174fc552",
    "AWS::EC2::VPCEndpointServicePermissions": "5841ea22a0cbb143",
    "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
    "AWS::EC2::VPCPeeringConnection": "e01a466d269170ed",
    "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
    "AWS::EC2::VPNConnection": "96656bab170e1c0b",
    "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
    "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
    "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
    "AWS::EC2::VerifiedAccessEndpoint": "7af4a2b3e9792243",
    "AWS::EC2::VerifiedAccessGroup": "7e9e151438b99d80",
    "AWS::EC2::VerifiedAccessInstance": "1f97d0789a7bae56",
    "AWS::EC2::VerifiedAccessTrustProvider": "4220d49771042d48",
    "AWS::EC2::Volume": "3385669f1c48cc6c",
    "AWS::EC2::VolumeAttachment": "1b60a799a0e3ac35",
    "AWS::ECR::PullThroughCacheRule": "7d1edc9fcc79dc1f",
    "AWS::ECR::PullTimeUpdateExclusion": "8f73d42f66f83eba",
    "AWS::ECR::RegistryPolicy": "80d3a81e49275d76",
    "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
    "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
    "AWS::ECR::Repository": "d569f41026af3be8",
    "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
    "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
    "AWS::ECS::CapacityProvider": "7dac44a9d26fc538",
    "AWS::ECS::Cluster": "3990111074eac8be",
    "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
    "AWS::ECS::ExpressGatewayService": "a04769bd1a468834",
    "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
    "AWS::ECS::Service": "585001d48158728c",
    "AWS::ECS::TaskDefinition": "ac3c5ff140cb5d7d",
    "AWS::ECS::TaskSet": "93284b06523a426d",
    "AWS::EFS::AccessPoint": "2f62161de474e688",
    "AWS::EFS::FileSystem": "1adec99cf2f47af3",
    "AWS::EFS::MountTarget": "eace751bcbd80a76",
    "AWS::EKS::AccessEntry": "6eb6ba186799e7f3",
    "AWS::EKS::Addon": "f27379fa02ce1e45",
    "AWS::EKS::Capability": "7816d4a96b146b20",
    "AWS::EKS::Cluster": "f17916cc287d09df",
    "AWS::EKS::FargateProfile": "71e821ce6e609193",
    "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
    "AWS::EKS::Nodegroup": "4b7b3ba6fffc3e8a",
    "AWS::EKS::PodIdentityAssociation": "d4249aaeb9409683",
    "AWS::EMR::Cluster": "ac0466c8197ef416",
    "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
    "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
    "AWS::EMR::SecurityConfiguration": "59f2b8145f1762e6",
    "AWS::EMR::Step": "87ecffcedd5d780a",
    "AWS::EMR::Studio": "5562dc4dee066fd3",
    "AWS::EMR::StudioSessionMapping": "68073ac17f83b5d4",
    "AWS::EMR::WALWorkspace": "1acf5569fff4fcbe",
    "AWS::EMRContainers::VirtualCluster": "d56c1799bc259539",
    "AWS::EMRServerless::Application": "b8f0bd50831c9f1e",
    "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
    "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
    "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
    "AWS::ElastiCache::ReplicationGroup": "59defd83ba1cb2f2",
    "AWS::ElastiCache::SecurityGroup": "075dfa59da275723",
    "AWS::ElastiCache::SecurityGroupIngress": "96d1b4a5bd438d25",
    "AWS::ElastiCache::ServerlessCache": "67ad14ea2425e853",
    "AWS::ElastiCache::SubnetGroup": "b331f1d336ff42bf",
    "AWS::ElastiCache::User": "6ade31b4f3953b51",
    "AWS::ElastiCache::UserGroup": "6a6c2c035fd2b2df",
    "AWS::ElasticBeanstalk::Application": "b0333be3e99bd8ce",
    "AWS::ElasticBeanstalk::ApplicationVersion": "9ffbca44711c927f",
    "AWS::ElasticBeanstalk::ConfigurationTemplate": "e3276863e80191ff",
    "AWS::ElasticBeanstalk::Environment": "d3a3171169a7d77e",
    "AWS::ElasticLoadBalancing::LoadBalancer": "0c104e32be4cf97e",
    "AWS::ElasticLoadBalancingV2::Listener": "5676e09eada66ea4",
    "AWS::ElasticLoadBalancingV2::ListenerCertificate": "3edd898ae1082797",
    "AWS::ElasticLoadBalancingV2::ListenerRule": "813e329d3a1f8231",
    "AWS::ElasticLoadBalancingV2::LoadBalancer": "f4f22fe5256925cc",
    "AWS::ElasticLoadBalancingV2::TargetGroup": "f7dbf6903e0a1263",
    "AWS::ElasticLoadBalancingV2::TrustStore": "7300a052ca504e65",
    "AWS::ElasticLoadBalancingV2::TrustStoreRevocation": "593a78e5ca9c2be3",
    "AWS::Elasticsearch::Domain": "c6414ef13f2fedbe",
    "AWS::EntityResolution::IdMappingWorkflow": "3eec6f2f33b6bf2f",
    "AWS::EntityResolution::IdNamespace": "361c6aaf0a6f9fb1",
    "AWS::EntityResolution::MatchingWorkflow": "37321076bd3e77de",
    "AWS::EntityResolution::PolicyStatement": "9f6a2078dc44533e",
    "AWS::EntityResolution::SchemaMapping": "fb0409fc120cfddf",
    "AWS::EventSchemas::Discoverer": "26c475458e43d0a3",
    "AWS::EventSchemas::Registry": "e90bca17695d13aa",
    "AWS::EventSchemas::RegistryPolicy": "f522642b76624a13",
    "AWS::EventSchemas::Schema": "1a9db6b605a5eee0",
    "AWS::Events::ApiDestination": "6029470910823e76",
    "AWS::Events::Archive": "95c9a00401f17bbf",
    "AWS::Events::Connection": "e5b12700232eb09a",
    "AWS::Events::Endpoint": "b53c3e84bcdd889e",
    "AWS::Events::EventBus": "87abb79a2ea2a571",
    "AWS::Events::EventBusPolicy": "7cb0a2b18483bb52",
    "AWS::Events::Rule": "4b8efe4a7f81f66f",
    "AWS::FIS::ExperimentTemplate": "0277c14e1157435b",
    "AWS::FIS::TargetAccountConfiguration": "c2959eedf6398b2a",
    "AWS::FMS::NotificationChannel": "8562504583cd6ad4",
    "AWS::FMS::Policy": "3d3868b1e974d27b",
    "AWS::FMS::ResourceSet": "6fb04db2dcf50bf8",
    "AWS::FSx::DataRepositoryAssociation": "2c944a4b33c2d639",
    "AWS::FSx::FileSystem": "9741d33840560c55",
    "AWS::FSx::S3AccessPointAttachment": "2f1f4654a56cd64d",
    "AWS::FSx::Snapshot": "656a8874092132a7",
    "AWS::FSx::StorageVirtualMachine": "b62638ce430b0942",
    "AWS::FSx::Volume": "e2217632738abb7f",
    "AWS::Forecast::Dataset": "d70bb680a23cd25a",
    "AWS::Forecast::DatasetGroup": "fd31f7450e21f1aa",
    "AWS::GameLift::Alias": "5c014b121a693be2",
    "AWS::GameLift::Build": "b9b218f4180db0c3",
    "AWS::GameLift::ContainerFleet": "8e4baca77c554031",
    "AWS::GameLift::ContainerGroupDefinition": "4f970fc059f7548b",
    "AWS::GameLift::Fleet": "08322d2081d018bb",
    "AWS::GameLift::GameServerGroup": "5cc95b605dfa9939",
    "AWS::GameLift::GameSessionQueue": "aba577170457cc78",
    "AWS::GameLift::Location": "74151dc88b4069da",
    "AWS::GameLift::MatchmakingConfiguration": "d94ba396d6b23182",
    "AWS::GameLift::MatchmakingRuleSet": "f6bc950e7c01648c",
    "AWS::GameLift::Script": "4571db51b8dc638d",
    "AWS::GlobalAccelerator::Accelerator": "8c74434fcd81b4e7",
    "AWS::GlobalAccelerator::CrossAccountAttachment": "8c37543e6efb0b27",
    "AWS::GlobalAccelerator::EndpointGroup": "f81aee5bef7cb0c1",
    "AWS::GlobalAccelerator::Listener": "86683fd976e55e88",
    "AWS::Glue::Classifier": "e64237d854ac7fec",
    "AWS::Glue::Connection": "687ff6bd75a9175e",
    "AWS::Glue::Crawler": "5232917448cb4257",
    "AWS::Glue::CustomEntityType": "b46c7cf573d72e3d",
    "AWS::Glue::DataCatalogEncryptionSettings": "e4d7c9e644714bf4",
    "AWS::Glue::DataQualityRuleset": "faf8cbb22cb87066",
    "AWS::Glue::Database": "6a65ca13bf420f12",
    "AWS::Glue::DevEndpoint": "e620bcbf039ad200",
    "AWS::Glue::IdentityCenterConfiguration": "9d46dfff393326b9",
    "AWS::Glue::Integration": "fca641d4c486281e",
    "AWS::Glue::IntegrationResourceProperty": "68dcd27a6ddbdfd8",
    "AWS::Glue::Job": "57e8fea46c9329ee",
    "AWS::Glue::MLTransform": "2c5a75b004c29815",
    "AWS::Glue::Partition": "b1116e6b758cc144",
    "AWS::Glue::Registry": "f29e746a5df78fb3",
    "AWS::Glue::Schema": "36f966bd9dff125a",
    "AWS::Glue::SchemaVersion": "70b6d2e7b702d49f",
    "AWS::Glue::SchemaVersionMetadata": "e531f6334f8eeda7",
    "AWS::Glue::SecurityConfiguration": "066142ba850e9899",
    "AWS::Glue::Table": "2528cdc058dacdf8",
    "AWS::Glue::TableOptimizer": "6b0597c4dd2d5360",
    "AWS::Glue::Trigger": "efdf04c0265f5aff",
    "AWS::Glue::UsageProfile": "c43f6252ac5a4f73",
    "AWS::Glue::Workflow": "7889f86fa2b1958f",
    "AWS::Grafana::Workspace": "3fe5732b1819bd0d",
    "AWS::Greengrass::ConnectorDefinition": "d81a2ea631976960",
    "AWS::Greengrass::ConnectorDefinitionVersion": "8f47953c935071e4",
    "AWS::Greengrass::CoreDefinition": "15c8baf34e5f8cad",
    "AWS::Greengrass::CoreDefinitionVersion": "2693a80c8060c381",
    "AWS::Greengrass::DeviceDefinition": "6ecc6ba96c8cc79d",
    "AWS::Greengrass::DeviceDefinitionVersion": "b502a71c845a7021",
    "AWS::Greengrass::FunctionDefinition": "8fd5402cad5a731f",
    "AWS::Greengrass::FunctionDefinitionVersion": "8a246bce38603a3b",
    "AWS::Greengrass::Group": "028bdeaf7ee3b4e1",
    "AWS::Greengrass::GroupVersion": "d150ea717ebf25a3",
    "AWS::Greengrass::LoggerDefinition": "ca08580793bf92db",
    "AWS::Greengrass::LoggerDefinitionVersion": "ea84d8c626f12182",
    "AWS::Greengrass::ResourceDefinition": "346ff6094dda5ee5",
    "AWS::Greengrass::ResourceDefinitionVersion": "3162bdad8992ee5c",
    "AWS::Greengrass::SubscriptionDefinition": "b24ced07fcb36f95",
    "AWS::Greengrass::SubscriptionDefinitionVersion": "1bc9c83f06823a39",
    "AWS::GreengrassV2::ComponentVersion": "66c2ae473cdf806c",
    "AWS::GreengrassV2::Deployment": "113077f9583c552f",
    "AWS::GroundStation::Config": "f82d483dee06e564",
    "AWS::GroundStation::DataflowEndpointGroup": "2e7b533bf2e45d93",
    "AWS::GroundStation::DataflowEndpointGroupV2": "20fb3b0b96644b6b",
    "AWS::GroundStation::MissionProfile": "7c8b1adcb4e267e6",
    "AWS::GuardDuty::Detector": "609c5ab9768f30a4",
    "AWS::GuardDuty::Filter": "3fd40922801a3b6a",
    "AWS::GuardDuty::IPSet": "82e2140b58b00302",
    "AWS::GuardDuty::MalwareProtectionPlan": "6bf3e2e96addd7f8",
    "AWS::GuardDuty::Master": "5115377f51b894ca",
    "AWS::GuardDuty::Member": "4410bf4350c9fdb8",
    "AWS::GuardDuty::PublishingDestination": "95c6a8d647a77c52",
    "AWS::GuardDuty::ThreatEntitySet": "f9e73b098cba1e1d",
    "AWS::GuardDuty::ThreatIntelSet": "09915bee5770f4c9",
    "AWS::GuardDuty::TrustedEntitySet": "150ef5b439192da2",
    "AWS::IAM::AccessKey": "7940f64975e793da",
    "AWS::IAM::Group": "8c9facb1f13f9457",
    "AWS::IAM::GroupPolicy": "58e37eeb095661a7",
    "AWS::IAM::InstanceProfile": "bf26619b978615f5",
    "AWS::IAM::ManagedPolicy": "d409538819ed546a",
    "AWS::IAM::OIDCProvider": "37a9a0d904b0c411",
    "AWS::IAM::Policy": "675bb1c6e349b968",
    "AWS::IAM::Role": "6b0320b7e7993d77",
    "AWS::IAM::RolePolicy": "3b144b67628ff5fc",
    "AWS::IAM::SAMLProvider": "a6f712f282976196",
    "AWS::IAM::ServerCertificate": "5840107f711b833c",
    "AWS::IAM::ServiceLinkedRole": "54931bc1a5b991c4",
    "AWS::IAM::User": "571fa9a137c01c78",
    "AWS::IAM::UserPolicy": "be8174f28c4bc37f",
    "AWS::IAM::UserToGroupAddition": "913f67f68af9fd37",
    "AWS::IAM::VirtualMFADevice": "7187a01cb3dd862f",
    "AWS::IVS::Channel": "916946ebdc8e55d5",
    "AWS::IVS::EncoderConfiguration": "1bbf442be3701670",
    "AWS::IVS::IngestConfiguration": "b86a3ad5a0af8f77",
    "AWS::IVS::PlaybackKeyPair": "3c61bae86ff3f1f2",
    "AWS::IVS::PlaybackRestrictionPolicy": "7987c0e21ff40983",
    "AWS::IVS::PublicKey": "44efe95717af3edb",
    "AWS::IVS::RecordingConfiguration": "cf2ba5d0f6fb49a4",
    "AWS::IVS::Stage": "b798fe917683ba33",
    "AWS::IVS::StorageConfiguration": "40581717f7881404",
    "AWS::IVS::StreamKey": "f2996c46a48fa083",
    "AWS::IVSChat::LoggingConfiguration": "dc0ff3615d0a518a",
    "AWS::IVSChat::Room": "96572f016397f14a",
    "AWS::IdentityStore::Group": "1b0e7a9a2bec57b5",
    "AWS::IdentityStore::GroupMembership": "d010a01463729806",
    "AWS::ImageBuilder::Component": "c686558ba853a496",
    "AWS::ImageBuilder::ContainerRecipe": "882a5a874ec51f81",
    "AWS::ImageBuilder::DistributionConfiguration": "7b34e1b0b9958d96",
    "AWS::ImageBuilder::Image": "7eaad9cf0d30061e",
    "AWS::ImageBuilder::ImagePipeline": "8ea2eca13ceb1fc8",
    "AWS::ImageBuilder::ImageRecipe": "83c0121011689366",
    "AWS::ImageBuilder::InfrastructureConfiguration": "703bdd9fb961cbcd",
    "AWS::ImageBuilder::LifecyclePolicy": "8cd39fa4bf49cfef",
    "AWS::ImageBuilder::Workflow": "ec02974c9f6e2cf5",
    "AWS::Inspector::AssessmentTarget": "b31528051aa52f7a",
    "AWS::Inspector::AssessmentTemplate": "388ca82049d0586e",
    "AWS::Inspector::ResourceGroup": "1f29e963e48e0260",
    "AWS::InspectorV2::CisScanConfiguration": "6a0dfa78d5d181cb",
    "AWS::InspectorV2::Filter": "075d0c9233498945",
    "AWS::InternetMonitor::Monitor": "acce608acc67f3a1",
    "AWS::Invoicing::InvoiceUnit": "c3cb849d6067deec",
    "AWS::IoT::AccountAuditConfiguration": "1df6ea7b44871f0a",
    "AWS::IoT::Authorizer": "c1bb226efdbe06df",
    "AWS::IoT::BillingGroup": "7356122caadbf1e6",
    "AWS::IoT::CACertificate": "777396c1bdf7b7e9",
    "AWS::IoT::Certificate": "9e87d1584bdfa627",
    "AWS::IoT::CertificateProvider": "ba58dd700876d1d2",
    "AWS::IoT::Command": "85dfdbc856bd6329",
    "AWS::IoT::CustomMetric": "95abcac33406bc29",
    "AWS::IoT::Dimension": "7abc67aee9bdb210",
    "AWS::IoT::DomainConfiguration": "bb375012e8bd7a84",
    "AWS::IoT::EncryptionConfiguration": "04291b59f537a48b",
    "AWS::IoT::FleetMetric": "fb5c21ce7d031532",
    "AWS::IoT::JobTemplate": "eae048ed2035c0e7",
    "AWS::IoT::Logging": "519a05631e6736c9",
    "AWS::IoT::MitigationAction": "35f9780b4ce4f2d1",
    "AWS::IoT::Policy": "0a051e10c89375bb",
    "AWS::IoT::PolicyPrincipalAttachment": "df0e6a915a42650b",
    "AWS::IoT::ProvisioningTemplate": "d9b34886a99d4afb",
    "AWS::IoT::ResourceSpecificLogging": "3472fe08f73d78f7",
    "AWS::IoT::RoleAlias": "47d4d78a34aa22b4",
    "AWS::IoT::ScheduledAudit": "985f3adc80a1fdc5",
    "AWS::IoT::SecurityProfile": "4f77596a1749304b",
    "AWS::IoT::SoftwarePackage": "6c7d8d10102d647b",
    "AWS::IoT::SoftwarePackageVersion": "09a582ea3f29b1d3",
    "AWS::IoT::Thing": "87d43589be8f9d6e",
    "AWS::IoT::ThingGroup": "7fa472878da23f08",
    "AWS::IoT::ThingPrincipalAttachment": "cb2db377e7001773",
    "AWS::IoT::ThingType": "472326c990487efa",
    "AWS::IoT::TopicRule": "4fcf915e11a87a98",
    "AWS::IoT::TopicRuleDestination": "1113af4de44b3cb0",
    "AWS::IoTEvents::AlarmModel": "9663bd41a6ba5243",
    "AWS::IoTEvents::DetectorModel": "0527d423b1402c41",
    "AWS::IoTEvents::Input": "30f33c5450a5de4f",
    "AWS::IoTSiteWise::AccessPolicy": "45b9535962dd9e69",
    "AWS::IoTSiteWise::Asset": "f09b8c708309cb16",
    "AWS::IoTSiteWise::AssetModel": "9837c85953c5875f",
    "AWS::IoTSiteWise::Dashboard": "b93236063adb4877",
    "AWS::IoTSiteWise::Gateway": "61f283dfa0cd3bb8",
    "AWS::IoTSiteWise::Portal": "a342ed3aaa4d8dbd",
    "AWS::IoTSiteWise::Project": "3c3bebc705ae8134",
    "AWS::IoTTwinMaker::ComponentType": "4047916d6f25a52d",
    "AWS::IoTTwinMaker::Entity": "87cfb0f09e609346",
    "AWS::IoTTwinMaker::Scene": "fef394e5c8e7cd21",
    "AWS::IoTTwinMaker::SyncJob": "61149eafc0e0b523",
    "AWS::IoTTwinMaker::Workspace": "8ac573a855e809f6",
    "AWS::KMS::Alias": "28f10f922a4d194f",
    "AWS::KMS::Key": "c70e396ee12ddb65",
    "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
    "AWS::KafkaConnect::Connector": "9ca5dec677704b80",
    "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
    "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
    "AWS::Kinesis::ResourcePolicy": "39996915810e234a",
    "AWS::Kinesis::Stream": "e6126822cd48b2b0",
    "AWS::Kinesis::StreamConsumer": "7ce125c877a406e0",
    "AWS::KinesisAnalytics::Application": "5282b56b53fcd2fd",
    "AWS::KinesisAnalytics::ApplicationOutput": "639fc1050aa8a059",
    "AWS::KinesisAnalytics::ApplicationReferenceDataSource": "a7b47c97e1845576",
    "AWS::KinesisAnalyticsV2::Application": "0c3ba846a178e940",
    "AWS::KinesisAnalyticsV2::ApplicationCloudWatchLoggingOption": "3e43e1b4b62bf3d7",
    "AWS::KinesisAnalyticsV2::ApplicationOutput": "14bce3d20b063bd9",
    "AWS::KinesisAnalyticsV2::ApplicationReferenceDataSource": "cb74b322fb27f7ec",
    "AWS::KinesisFirehose::DeliveryStream": "6e5b365496a735c9",
    "AWS::KinesisVideo::SignalingChannel": "5cce0278c62fce3f",
    "AWS::KinesisVideo::Stream": "2f8799a229777862",
    "AWS::LakeFormation::DataCellsFilter": "6ac217ac96918929",
    "AWS::LakeFormation::DataLakeSettings": "d9b68c11de60cdd0",
    "AWS::LakeFormation::Permissions": "062fc8932c9970c4",
    "AWS::LakeFormation::PrincipalPermissions": "89fd48f71918cde3",
    "AWS::LakeFormation::Resource": "64382446e2262067",
    "AWS::LakeFormation::Tag": "e6965562c3f7e5bb",
    "AWS::LakeFormation::TagAssociation": "22d7f7ee98ca2b17",
    "AWS::Lambda::Alias": "88c6e095730810db",
    "AWS::Lambda::CodeSigningConfig": "715ffad26c1d349b",
    "AWS::Lambda::EventInvokeConfig": "eb90a4c91675fe09",
    "AWS::Lambda::EventSourceMapping": "ab79afd9e900b271",
    "AWS::Lambda::Function": "a0138839187c3dd7",
    "AWS::Lambda::LayerVersion": "f00fbc621c084236",
    "AWS::Lambda::LayerVersionPermission": "5eb94a7b3ed6da6c",
    "AWS::Lambda::Permission": "a43a5328bea4f6ad",
    "AWS::Lambda::Url": "92a0bf520e2af3a2",
    "AWS::Lambda::Version": "e7fcd54deb138582",
    "AWS::LaunchWizard::Deployment": "2532c1afdd9c1f65",
    "AWS::Lex::Bot": "ea8cdccdd59efeb2",
    "AWS::Lex::BotAlias": "84393fe543937571",
    "AWS::Lex::BotVersion": "f2b3e02257c2355d",
    "AWS::Lex::ResourcePolicy": "c3caa37b709081d7",
    "AWS::LicenseManager::Grant": "09ac50c1180e4f9f",
    "AWS::LicenseManager::License": "12e9aca3199765e2",
    "AWS::Lightsail::Alarm": "3c79ce73cc887269",
    "AWS::Lightsail::Bucket": "6d9faeebb1f4d32e",
    "AWS::Lightsail::Certificate": "bfc5f606b18a1078",
    "AWS::Lightsail::Container": "ebf6e798bce30f95",
    "AWS::Lightsail::Database": "e7b4ed550fb14278",
    "AWS::Lightsail::Disk": "fc7f1ae42f139e6b",
    "AWS::Lightsail::DiskSnapshot": "4760b2800150a7b2",
    "AWS::Lightsail::Instance": "7b3b6dc250f9c9b7",
    "AWS::Lightsail::InstanceSnapshot": "b69ff9ee5c37a8a7",
    "AWS::Lightsail::LoadBalancer": "5160879251242be5",
    "AWS::Lightsail::LoadBalancerTlsCertificate": "b37658eaa4d42b5b",
    "AWS::Lightsail::StaticIp": "690bc8704bff718d",
    "AWS::Logs::AccountPolicy": "02fea54f4157dda9",
    "AWS::Logs::Delivery": "ddc55d6dc002371f",
    "AWS::Logs::DeliveryDestination": "30b61a3515971eda",
    "AWS::Logs::DeliverySource": "67b64320b397d6cd",
    "AWS::Logs::Destination": "ff1e6b020f2cf8e7",
    "AWS::Logs::Integration": "0bc4c86432380358",
    "AWS::Logs::LogAnomalyDetector": "e2ee984f7c775ef5",
    "AWS::Logs::LogGroup": "364a0898ae2cfeb8",
    "AWS::Logs::LogStream": "bb97d1fb38ff99db",
    "AWS::Logs::MetricFilter": "9a1d875b35cd0f81",
    "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
    "AWS::Logs::ResourcePolicy": "d7898253a7730ac3",
    "AWS::Logs::SubscriptionFilter": "57635d7dc5bd3e61",
    "AWS::Logs::Transformer": "66b4b09c596d83c0",
    "AWS::LookoutEquipment::InferenceScheduler": "854115f97396fd8e",
    "AWS::LookoutVision::Project": "89603d4b475081ea",
    "AWS::M2::Application": "7c1b78891b93a215",
    "AWS::M2::Deployment": "a4f5b6e67e1de730",
    "AWS::M2::Environment": "556251194fbbcc67",
    "AWS::MSK::BatchScramSecret": "ff2b807a577495b0",
    "AWS::MSK::Cluster": "d2642928d6736e1c",
    "AWS::MSK::ClusterPolicy": "b60740da22ea8c04",
    "AWS::MSK::Configuration": "61dbb22c2b6cbbb1",
    "AWS::MSK::Replicator": "5b655e344006b494",
    "AWS::MSK::ServerlessCluster": "9eb8b6f85a407e2e",
    "AWS::MSK::VpcConnection": "6aeb07916b90c80a",
    "AWS::MWAA::Environment": "c28ab3624f1d638c",
    "AWS::MWAAServerless::Workflow": "52e9442d497d660d",
    "AWS::Macie::AllowList": "40bd0a0377639bda",
    "AWS::Macie::CustomDataIdentifier": "c0c5ba901caafe31",
    "AWS::Macie::FindingsFilter": "d3c6be2a3d872987",
    "AWS::Macie::Session": "d3f89daf6dae9887",
    "AWS::ManagedBlockchain::Accessor": "ebe7255aa869f28f",
    "AWS::ManagedBlockchain::Member": "b1387f3a906e5414",
    "AWS::ManagedBlockchain::Node": "d6eec4d407c772d4",
    "AWS::MediaConnect::Bridge": "1dce5b6c6efd2a16",
    "AWS::MediaConnect::BridgeOutput": "420f29af1eb058cb",
    "AWS::MediaConnect::BridgeSource": "0e38568055415e91",
    "AWS::MediaConnect::Flow": "edeb56671107a65e",
    "AWS::MediaConnect::FlowEntitlement": "a037428c13b170c6",
    "AWS::MediaConnect::FlowOutput": "524c165d1ca23309",
    "AWS::MediaConnect::FlowSource": "2b9288ecf90ca28a",
    "AWS::MediaConnect::FlowVpcInterface": "e914ee9ef9b59d86",
    "AWS::MediaConnect::Gateway": "0d7409482162e3d4",
    "AWS::MediaConnect::RouterInput": "89cef0e2e2e12890",
    "AWS::MediaConnect::RouterNetworkInterface": "af6cfbf663eeeaaa",
    "AWS::MediaConnect::RouterOutput": "b57692f35a90a9c7",
    "AWS::MediaConvert::JobTemplate": "de2041b421ca905f",
    "AWS::MediaConvert::Preset": "910599ec8d17a7da",
    "AWS::MediaConvert::Queue": "f5e916f2b2a64b66",
    "AWS::MediaLive::Channel": "8a0a01c6ed190ddd",
    "AWS::MediaLive::ChannelPlacementGroup": "c5a90eecc19bba43",
    "AWS::MediaLive::CloudWatchAlarmTemplate": "81fb2ce45d067a00",
    "AWS::MediaLive::CloudWatchAlarmTemplateGroup": "6ce0be92d99cb079",
    "AWS::MediaLive::Cluster": "1a1f4c1068fa62ac",
    "AWS::MediaLive::EventBridgeRuleTemplate": "546f92cd028358f3",
    "AWS::MediaLive::EventBridgeRuleTemplateGroup": "d600d2e2b26dcff9",
    "AWS::MediaLive::Input": "a4b78d22a36e5221",
    "AWS::MediaLive::InputSecurityGroup": "25d503b540e5b2f1",
    "AWS::MediaLive::Multiplex": "01d8204ac37d509d",
    "AWS::MediaLive::Multiplexprogram": "158d6f9e8427ca85",
    "AWS::MediaLive::Network": "331feab410c0cd98",
    "AWS::MediaLive::SdiSource": "0758f27a64ded787",
    "AWS::MediaLive::SignalMap": "4469cefa6a45f1f7",
    "AWS::MediaPackage::Asset": "46a05885cb8e8a23",
    "AWS::MediaPackage::Channel": "e7456b39d936b909",
    "AWS::MediaPackage::OriginEndpoint": "35ba5a2f6d533dd0",
    "AWS::MediaPackage::PackagingConfiguration": "381cdf03053e7a94",
    "AWS::MediaPackage::PackagingGroup": "ef7cc14fb78ab5d0",
    "AWS::MediaPackageV2::Channel": "62a1a362e9e8f627",
    "AWS::MediaPackageV2::ChannelGroup": "2aa9c5f3fad67e76",
    "AWS::MediaPackageV2::ChannelPolicy": "e79aba75cf23e354",
    "AWS::MediaPackageV2::OriginEndpoint": "ebe0f0a5cdb97975",
    "AWS::MediaPackageV2::OriginEndpointPolicy": "8cd12a52dceffffe",
    "AWS::MediaStore::Container": "3566cc35a249c49c",
    "AWS::MediaTailor::Channel": "fe2dcc2566975851",
    "AWS::MediaTailor::ChannelPolicy": "1c9cf783f5b18afb",
    "AWS::MediaTailor::LiveSource": "a884632fe226b938",
    "AWS::MediaTailor::PlaybackConfiguration": "45549228850e8811",
    "AWS::MediaTailor::SourceLocation": "7ddd02a26d6de0a4",
    "AWS::MediaTailor::VodSource": "746fa4c2fdf8d70a",
    "AWS::MemoryDB::ACL": "92db73d1650765a6",
    "AWS::MemoryDB::Cluster": "6b7ebaa919714fa9",
    "AWS::MemoryDB::MultiRegionCluster": "823495e9da9d8501",
    "AWS::MemoryDB::ParameterGroup": "694beb8bcf66b646",
    "AWS::MemoryDB::SubnetGroup": "058d84a44c7cdeb2",
    "AWS::MemoryDB::User": "2c12ec2e734bb40c",
    "AWS::Neptune::DBCluster": "8d9215c18d4689e5",
    "AWS::Neptune::DBClusterParameterGroup": "d3f072d3d16a7a5f",
    "AWS::Neptune::DBInstance": "40928fad97bbb2cd",
    "AWS::Neptune::DBParameterGroup": "6b2f9cd1b2702ccf",
    "AWS::Neptune::DBSubnetGroup": "c59d053f84ba853c",
    "AWS::Neptune::EventSubscription": "291cb01f3cbffb3e",
    "AWS::NeptuneGraph::Graph": "4a3e36b32b0fc6ff",
    "AWS::NeptuneGraph::PrivateGraphEndpoint": "1bcd2ff6cb6de3cf",
    "AWS::NetworkFirewall::Firewall": "e72dd64edb0563ec",
    "AWS::NetworkFirewall::FirewallPolicy": "23d185da5cfdceca",
    "AWS::NetworkFirewall::LoggingConfiguration": "24065655a3066a83",
    "AWS::NetworkFirewall::RuleGroup": "0a775a8261b19aad",
    "AWS::NetworkFirewall::TLSInspectionConfiguration": "c67eab10509c4b9d",
    "AWS::NetworkFirewall::VpcEndpointAssociation": "5862c6e91def980a",
    "AWS::NetworkManager::ConnectAttachment": "dff93d8dcf79e425",
    "AWS::NetworkManager::ConnectPeer": "64fbde44ba2ff1a1",
    "AWS::NetworkManager::CoreNetwork": "c62c7ea789322d84",
    "AWS::NetworkManager::CoreNetworkPrefixListAssociation": "636b5531fb98452c",
    "AWS::NetworkManager::CustomerGatewayAssociation": "61803ddea55493f6",
    "AWS::NetworkManager::Device": "962454214c18d318",
    "AWS::NetworkManager::DirectConnectGatewayAttachment": "9318dca51df45548",
    "AWS::NetworkManager::GlobalNetwork": "dc2e8c87534d0b78",
    "AWS::NetworkManager::Link": "ec363986a0d5f73a",
    "AWS::NetworkManager::LinkAssociation": "c78f6eaf3131bc07",
    "AWS::NetworkManager::Site": "dc02f56926649ccd",
    "AWS::NetworkManager::SiteToSiteVpnAttachment": "84a7722c038bd7c2",
    "AWS::NetworkManager::TransitGatewayPeering": "b8d9ea146d3e65b8",
    "AWS::NetworkManager::TransitGatewayRegistration": "74db34f319125881",
    "AWS::NetworkManager::TransitGatewayRouteTableAttachment": "1d6879f627bf88e4",
    "AWS::NetworkManager::VpcAttachment": "2e2ebc8d6a69d76c",
    "AWS::OSIS::Pipeline": "7d12e06885198d09",
    "AWS::Oam::Link": "4d4e114e0f615d82",
    "AWS::Oam::Sink": "81957ea027e4c201",
    "AWS::ObservabilityAdmin::OrganizationCentralizationRule": "6921de30f2cef3a3",
    "AWS::ObservabilityAdmin::OrganizationTelemetryRule": "4f702fc11306cf74",
    "AWS::ObservabilityAdmin::S3TableIntegration": "9dcd4f79cf41f229",
    "AWS::ObservabilityAdmin::TelemetryPipelines": "1acc5affc6615ad2",
    "AWS::ObservabilityAdmin::TelemetryRule": "a54d5e794c37e6c1",
    "AWS::Omics::RunGroup": "d8207e80701331b7",
    "AWS::Omics::Workflow": "0aa45813967de107",
    "AWS::Omics::WorkflowVersion": "293e6e45ad5e99b1",
    "AWS::OpenSearchServerless::AccessPolicy": "ec7a348a493d8c4f",
    "AWS::OpenSearchServerless::Collection": "be876510f965bd06",
    "AWS::OpenSearchServerless::Index": "fcc40949c8a1e83a",
    "AWS::OpenSearchServerless::LifecyclePolicy": "71de0a66a6f0daa7",
    "AWS::OpenSearchServerless::SecurityConfig": "a23bf8d6e6bab2ea",
    "AWS::OpenSearchServerless::SecurityPolicy": "a73437e0f606fd57",
    "AWS::OpenSearchServerless::VpcEndpoint": "2d8078631404affc",
    "AWS::OpenSearchService::Application": "866ac7c65f261ec4",
    "AWS::OpenSearchService::Domain": "1c09878d526db02c",
    "AWS::OpsWorks::App": "508d500b32261320",
    "AWS::OpsWorks::ElasticLoadBalancerAttachment": "4902f6030931194b",
    "AWS::OpsWorks::Instance": "2d5afc2d419e057d",
    "AWS::OpsWorks::Layer": "c0f477e5b002651a",
    "AWS::OpsWorks::Stack": "29ffdc808f9c83e1",
    "AWS::OpsWorks::UserProfile": "c81a3392e657795c",
    "AWS::OpsWorks::Volume": "2de519e2f08e58bd",
    "AWS::Organizations::Account": "5e4fa45032c79057",
    "AWS::Organizations::Organization": "ef5f3cbaa91637bd",
    "AWS::Organizations::OrganizationalUnit": "97d519f28c43e840",
    "AWS::Organizations::Policy": "11262354a02bb72d",
    "AWS::Organizations::ResourcePolicy": "44e0f38bebacad2e",
    "AWS::PCAConnectorAD::Connector": "956000172e4b20cd",
    "AWS::PCAConnectorAD::DirectoryRegistration": "1dc615cca69549dd",
    "AWS::PCAConnectorAD::ServicePrincipalName": "6a8ea7b9a179bc85",
    "AWS::PCAConnectorAD::Template": "ed0b568c05022bdf",
    "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry": "756784fc38981208",
    "AWS::PCAConnectorSCEP::Challenge": "66f2129c2055583e",
    "AWS::PCAConnectorSCEP::Connector": "9cbd2b6a05e6eb0d",
    "AWS::Personalize::Dataset": "9e7cafcfcba638cb",
    "AWS::Personalize::DatasetGroup": "d4a5c5722f39080e",
    "AWS::Personalize::Schema": "52e43b4875fdf0f3",
    "AWS::Personalize::Solution": "bf8a32c997c789a9",
    "AWS::Pinpoint::ADMChannel": "fc1f95e86736d23b",
    "AWS::Pinpoint::APNSChannel": "c0374468e811dfbd",
    "AWS::Pinpoint::APNSSandboxChannel": "6fdd937d9f67edc1",
    "AWS::Pinpoint::APNSVoipChannel": "96e6a6ae7029cde7",
    "AWS::Pinpoint::APNSVoipSandboxChannel": "eebb0ccd17def568",
    "AWS::Pinpoint::App": "43da08dc5916b632",
    "AWS::Pinpoint::ApplicationSettings": "0e93dafb322d8568",
    "AWS::Pinpoint::BaiduChannel": "0e7bd6bbfc34c097",
    "AWS::Pinpoint::Campaign": "f67d2e17257b50a6",
    "AWS::Pinpoint::EmailChannel": "ec605e4f4fbcef50",
    "AWS::Pinpoint::EmailTemplate": "d2b596f097cc22b4",
    "AWS::Pinpoint::EventStream": "ce57c14a352ab4b8",
    "AWS::Pinpoint::GCMChannel": "eeac9035b8838f6a",
    "AWS::Pinpoint::InAppTemplate": "43989f90e80d0668",
    "AWS::Pinpoint::PushTemplate": "0f00812a014e0b18",
    "AWS::Pinpoint::SMSChannel": "1f7d608c4f79d912",
    "AWS::Pinpoint::Segment": "2cdab21d902eeaaf",
    "AWS::Pinpoint::SmsTemplate": "14a13948673ada94",
    "AWS::Pinpoint::VoiceChannel": "dd18f5256366f639",
    "AWS::Pipes::Pipe": "052457cd8332df71",
    "AWS::Proton::EnvironmentAccountConnection": "7ea18f79786bbafc",
    "AWS::Proton::EnvironmentTemplate": "ca9dca703d458ee2",
    "AWS::Proton::ServiceTemplate": "d29d4f46a846815a",
    "AWS::QLDB::Ledger": "eb38fe7089c60665",
    "AWS::QLDB::Stream": "09aa8fbe0fae7277",
    "AWS::QuickSight::Analysis": "9ed141915b114fbd",
    "AWS::QuickSight::CustomPermissions": "da6da182c0c23fb4",
    "AWS::QuickSight::Dashboard": "b1b7368590994f86",
    "AWS::QuickSight::DataSet": "0e9e94a2fd9e8f95",
    "AWS::QuickSight::DataSource": "407708b753626383",
    "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
    "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
    "AWS::QuickSight::Template": "9f99a52291094b16",
    "AWS::QuickSight::Theme": "c85a23cc7ca1d55e",
    "AWS::QuickSight::VPCConnection": "96804832324c84da",
    "AWS::RAM::Permission": "740a6e8ada63a5a3",
    "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
    "AWS::RDS::CustomDBEngineVersion": "67b3a7d6ee10021d",
    "AWS::RDS::DBCluster": "9c7540d3d4699497",
    "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
    "AWS::RDS::DBInstance": "25726c9e8467f4c5",
    "AWS::RDS::DBParameterGroup": "d29cf38b861f6048",
    "AWS::RDS::DBProxy": "308e70305b33a892",
    "AWS::RDS::DBProxyEndpoint": "17943cc672d084c2",
    "AWS::RDS::DBProxyTargetGroup": "b584b6fb42fcd4c7",
    "AWS::RDS::DBSecurityGroup": "42f555e782cd9946",
    "AWS::RDS::DBSecurityGroupIngress": "1a14ad6e73c0b6b7",
    "AWS::RDS::DBShardGroup": "df6b36c7e099595a",
    "AWS::RDS::DBSubnetGroup": "4a2ab41cbcc2adb8",
    "AWS::RDS::EventSubscription": "85bf3af749d312f0",
    "AWS::RDS::GlobalCluster": "a87d030f06c19d47",
    "AWS::RDS::Integration": "f7415a6a9c4a11da",
    "AWS::RDS::OptionGroup": "d89f528bd7bdd696",
    "AWS::RUM::AppMonitor": "7d61f34df1716a89",
    "AWS::Rbin::Rule": "6c9b3a0b86f4c148",
    "AWS::Redshift::Cluster": "bd4c5acbf9c19128",
    "AWS::Redshift::ClusterParameterGroup": "37da89c6de1fa7a4",
    "AWS::Redshift::ClusterSecurityGroup": "6a629309a94b6faa",
    "AWS::Redshift::ClusterSecurityGroupIngress": "0079cffa4eeb3685",
    "AWS::Redshift::ClusterSubnetGroup": "15d4337dca25524a",
    "AWS::Redshift::EndpointAccess": "b9824e20c8b887c4",
    "AWS::Redshift::EndpointAuthorization": "e72be424d109da1d",
    "AWS::Redshift::EventSubscription": "53db04ab09eaba8e",
    "AWS::Redshift::Integration": "a386ce60053e2aa9",
    "AWS::Redshift::ScheduledAction": "51bcaaee4f45725e",
    "AWS::RedshiftServerless::Namespace": "5713f5387741d15b",
    "AWS::RedshiftServerless::Snapshot": "826c5d08e248c956",
    "AWS::RedshiftServerless::Workgroup": "d725f73083591093",
    "AWS::RefactorSpaces::Application": "5ce66b11c8880313",
    "AWS::RefactorSpaces::Environment": "66d4eac8cbae2aa3",
    "AWS::RefactorSpaces::Route": "e534704df04595db",
    "AWS::RefactorSpaces::Service": "968b1f7793cbe13b",
    "AWS::Rekognition::Collection": "4587b01d0cca1bb9",
    "AWS::Rekognition::Project": "ce13fcded0893cd8",
    "AWS::ResilienceHub::App": "c446dbf344853a89",
    "AWS::ResilienceHub::ResiliencyPolicy": "dbbbdfc467be5ad1",
    "AWS::ResourceExplorer2::DefaultViewAssociation": "a7cd7349891d3ea3",
    "AWS::ResourceExplorer2::Index": "b67cbdd9ae9d9f39",
    "AWS::ResourceExplorer2::View": "5e2f158811bfdae6",
    "AWS::ResourceGroups::Group": "c777809feaeb0e2b",
    "AWS::ResourceGroups::TagSyncTask": "9683ef6d409e4585",
    "AWS::RolesAnywhere::CRL": "e5f5be456a9e1f7c",
    "AWS::RolesAnywhere::Profile": "efa966abbef1d995",
    "AWS::RolesAnywhere::TrustAnchor": "6b14ddb523aec5e8",
    "AWS::Route53::CidrCollection": "2332f11a72446133",
    "AWS::Route53::DNSSEC": "106ee68fc4cc0a3c",
    "AWS::Route53::HealthCheck": "f075f8dd247254c7",
    "AWS::Route53::HostedZone": "29b2fce456164442",
    "AWS::Route53::KeySigningKey": "a9a67ae6c371fcf4",
    "AWS::Route53::RecordSet": "c01e9eccec2e3b83",
    "AWS::Route53::RecordSetGroup": "8300e7c48d942273",
    "AWS::Route53Profiles::Profile": "cb0a28f9bebd044e",
    "AWS::Route53Profiles::ProfileAssociation": "fa568e44f7d9e9f2",
    "AWS::Route53Profiles::ProfileResourceAssociation": "73d6b9da50afa75b",
    "AWS::Route53Resolver::FirewallDomainList": "76957613d7f85b1b",
    "AWS::Route53Resolver::FirewallRuleGroup": "c0eed6795a190c56",
    "AWS::Route53Resolver::FirewallRuleGroupAssociation": "d84c68a6ebbb5876",
    "AWS::Route53Resolver::OutpostResolver": "4da7faadc267504a",
    "AWS::Route53Resolver::ResolverConfig": "174be26547caaa42",
    "AWS::Route53Resolver::ResolverDNSSECConfig": "813fd8fe1e24c6e3",
    "AWS::Route53Resolver::ResolverEndpoint": "d0ad42bf85f59279",
    "AWS::Route53Resolver::ResolverQueryLoggingConfig": "78d814f813fdbcbf",
    "AWS::Route53Resolver::ResolverQueryLoggingConfigAssociation": "38f173a35a807a46",
    "AWS::Route53Resolver::ResolverRule": "a5bf3dc0f2b44d80",
    "AWS::Route53Resolver::ResolverRuleAssociation": "3e5cdfc8643c083b",
    "AWS::S3::AccessGrant": "b1e7af0495a078b0",
    "AWS::S3::AccessGrantsInstance": "05d3e874b43bbad8",
    "AWS::S3::AccessGrantsLocation": "3a7be1727f630029",
    "AWS::S3::AccessPoint": "e8b95810dd8d6917",
    "AWS::S3::Bucket": "bc2a891a463ee5ee",
    "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
    "AWS::S3::MultiRegionAccessPoint": "193323be1bf2dac0",
    "AWS::S3::MultiRegionAccessPointPolicy": "7ac84076052ddd16",
    "AWS::S3::StorageLens": "842abc50870a3bcf",
    "AWS::S3::StorageLensGroup": "a48c03e67d334c14",
    "AWS::S3ObjectLambda::AccessPoint": "2d6b2b82a9508114",
    "AWS::S3ObjectLambda::AccessPointPolicy": "fd6328c6c782223a",
    "AWS::S3Outposts::AccessPoint": "cbb3c4e369a53e6c",
    "AWS::S3Outposts::Bucket": "1dda72967f283796",
    "AWS::S3Outposts::BucketPolicy": "29126ab2fb9793f6",
    "AWS::S3Outposts::Endpoint": "323c92664ebd7f95",
    "AWS::S3Tables::Namespace": "44b5d6ca79e89650",
    "AWS::S3Tables::Table": "9fef59bdfa5bd960",
    "AWS::S3Tables::TableBucket": "f26569515da002c0",
    "AWS::S3Tables::TableBucketPolicy": "b3ab0f647d7aed60",
    "AWS::S3Tables::TablePolicy": "0ed301e1967bd6a0",
    "AWS::S3Vectors::Index": "6438f7c0860db9d2",
    "AWS::S3Vectors::VectorBucket": "eae6d86b8ee33282",
    "AWS::S3Vectors::VectorBucketPolicy": "ecd7e75e3e0d291d",
    "AWS::SDB::Domain": "48c38397df169b43",
    "AWS::SES::ConfigurationSet": "97470ae3c0d408ae",
    "AWS::SES::ConfigurationSetEventDestination": "f4e74b1d7e859c34",
    "AWS::SES::ContactList": "c5a40d0f3d530e19",
    "AWS::SES::DedicatedIpPool": "1485a5989d771f62",
    "AWS::SES::EmailIdentity": "be6211158f395729",
    "AWS::SES::MailManagerAddonInstance": "2012772f13a846eb",
    "AWS::SES::MailManagerAddonSubscription": "63e6d6434e3ac413",
    "AWS::SES::MailManagerAddressList": "22302ded05b5fc2a",
    "AWS::SES::MailManagerArchive": "3f33022e6c705d6d",
    "AWS::SES::MailManagerIngressPoint": "923b3c23a9a15b1b",
    "AWS::SES::MailManagerRelay": "92102c7d273b1d47",
    "AWS::SES::MailManagerRuleSet": "8fd084ee266114ee",
    "AWS::SES::MailManagerTrafficPolicy": "e229aa555378d193",
    "AWS::SES::MultiRegionEndpoint": "23f0206212864cb3",
    "AWS::SES::ReceiptFilter": "f16f5cdaa2594ab2",
    "AWS::SES::ReceiptRule": "6641e8f6c31a50e6",
    "AWS::SES::ReceiptRuleSet": "79ecdd974ccaeb6a",
    "AWS::SES::Template": "20af669206370beb",
    "AWS::SES::Tenant": "0c003f20faaf4446",
    "AWS::SES::VdmAttributes": "15df0379061c0489",
    "AWS::SMSVOICE::ConfigurationSet": "2bdda88e956e2a26",
    "AWS::SMSVOICE::OptOutList": "005f2438fbf815f8",
    "AWS::SMSVOICE::PhoneNumber": "bb506276e3b95e6c",
    "AWS::SMSVOICE::Pool": "b3625249271cb2c4",
    "AWS::SMSVOICE::ProtectConfiguration": "2323c25bc333ab42",
    "AWS::SMSVOICE::ResourcePolicy": "1e13b6a86622c5ce",
    "AWS::SMSVOICE::SenderId": "28ee6b42794a5db3",
    "AWS::SNS::Subscription": "9426c559a25e9da6",
    "AWS::SNS::Topic": "dfcf55503343941a",
    "AWS::SNS::TopicInlinePolicy": "e47e6b028a7c3cc7",
    "AWS::SNS::TopicPolicy": "04470a92c9a1130c",
    "AWS::SQS::Queue": "4b3c7b55a266949b",
    "AWS::SQS::QueueInlinePolicy": "e4132d6c68dcbc6c",
    "AWS::SQS::QueuePolicy": "8d0c3b8154e71ff3",
    "AWS::SSM::Association": "ad263c9023f92e0c",
    "AWS::SSM::Document": "8b3a8b629d6edee1",
    "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
    "AWS::SSM::MaintenanceWindowTarget": "16bcb928c1d2233d",
    "AWS::SSM::MaintenanceWindowTask": "ce68f32e2ef0a575",
    "AWS::SSM::Parameter": "c247b226112c5ae5",
    "AWS::SSM::PatchBaseline": "43cce065b6753223",
    "AWS::SSM::ResourceDataSync": "f92ce1aa6674b7f2",
    "AWS::SSM::ResourcePolicy": "888e448281ad980b",
    "AWS::SSMContacts::Contact": "3a02a58457318b77",
    "AWS::SSMContacts::ContactChannel": "50902ebe704d3d35",
    "AWS::SSMContacts::Plan": "13c6ac8f8a6e02ce",
    "AWS::SSMContacts::Rotation": "6441554f8fc52158",
    "AWS::SSMGuiConnect::Preferences": "375a013f12938691",
    "AWS::SSMIncidents::ReplicationSet": "dca24b97928c9ea5",
    "AWS::SSMIncidents::ResponsePlan": "05319d0392a188a5",
    "AWS::SSMQuickSetup::ConfigurationManager": "b96cc7a26f1de87a",
    "AWS::SSMQuickSetup::LifecycleAutomation": "13a6078578946e79",
    "AWS::SSO::Application": "996ad386536ff750",
    "AWS::SSO::ApplicationAssignment": "ae6daf9e56a38982",
    "AWS::SSO::Assignment": "3e0b05f0a3cba8d8",
    "AWS::SSO::Instance": "12637265e4117853",
    "AWS::SSO::InstanceAccessControlAttributeConfiguration": "ccfedd9599046cb1",
    "AWS::SSO::PermissionSet": "e4212a96dd4b627d",
    "AWS::SageMaker::App": "a2a6c6e24ea97c09",
    "AWS::SageMaker::AppImageConfig": "c4676a45bc3fb01f",
    "AWS::SageMaker::CodeRepository": "d59f5cf4521ff1c2",
    "AWS::SageMaker::DataQualityJobDefinition": "aa9b4c65d2154f84",
    "AWS::SageMaker::Domain": "d0c9a5567721ed89",
    "AWS::SageMaker::Endpoint": "73ec8bbe3002c627",
    "AWS::SageMaker::EndpointConfig": "7c3a65bd96c2e9a3",
    "AWS::SageMaker::FeatureGroup": "dac504afb40ef88a",
    "AWS::SageMaker::Image": "407ba0b85aaa0559",
    "AWS::SageMaker::ImageVersion": "307ec283c9c38549",
    "AWS::SageMaker::InferenceComponent": "a87f6b6b8154f062",
    "AWS::SageMaker::InferenceExperiment": "72f969d0b786e427",
    "AWS::SageMaker::MlflowTrackingServer": "d04cb0d6f0cdfaa2",
    "AWS::SageMaker::Model": "9757bf2bdc6a25ef",
    "AWS::SageMaker::ModelBiasJobDefinition": "dd84beccd3fcf2f2",
    "AWS::SageMaker::ModelCard": "3eb6d59e80cf06f6",
    "AWS::SageMaker::ModelExplainabilityJobDefinition": "19aca2d9f619e82d",
    "AWS::SageMaker::ModelPackage": "14150fce0eeff149",
    "AWS::SageMaker::ModelPackageGroup": "b94ce3bd335b44cd",
    "AWS::SageMaker::ModelQualityJobDefinition": "9e16a45c759da5fb",
    "AWS::SageMaker::MonitoringSchedule": "aa0115534ffe6a87",
    "AWS::SageMaker::NotebookInstance": "f222a6268560b3b6",
    "AWS::SageMaker::NotebookInstanceLifecycleConfig": "f0d21af114094fa4",
    "AWS::SageMaker::PartnerApp": "f8b0a148c260cb56",
    "AWS::SageMaker::Pipeline": "34dda455906546ac",
    "AWS::SageMaker::ProcessingJob": "9bf6e74e7f3d53e1",
    "AWS::SageMaker::Project": "c10c82bc5a09a5dc",
    "AWS::SageMaker::Space": "a50f6b85f86355b5",
    "AWS::SageMaker::StudioLifecycleConfig": "5b453bb7816eb95b",
    "AWS::SageMaker::UserProfile": "6300c02533605472",
    "AWS::SageMaker::Workteam": "d617e40122a8fe93",
    "AWS::Scheduler::Schedule": "e8b60514af25a837",
    "AWS::Scheduler::ScheduleGroup": "ef710d09dbb243bf",
    "AWS::SecretsManager::ResourcePolicy": "cb5d330bf15d9d5a",
    "AWS::SecretsManager::RotationSchedule": "e02692fb717f1c08",
    "AWS::SecretsManager::Secret": "9ee06ee7d6dbf7cf",
    "AWS::SecretsManager::SecretTargetAttachment": "3bf4404734c82308",
    "AWS::SecurityHub::AggregatorV2": "db793a0321d907b8",
    "AWS::SecurityHub::AutomationRule": "f6c9ad12353e867b",
    "AWS::SecurityHub::AutomationRuleV2": "382b90fb3949f096",
    "AWS::SecurityHub::ConfigurationPolicy": "acb80ff79b887cb5",
    "AWS::SecurityHub::ConnectorV2": "b4e780d54c354d65",
    "AWS::SecurityHub::DelegatedAdmin": "a328fc62a9f2f7e2",
    "AWS::SecurityHub::FindingAggregator": "7a4c95623ee48fcd",
    "AWS::SecurityHub::Hub": "9f6cb2d8967bfcf6",
    "AWS::SecurityHub::HubV2": "b1544234a77fc9a5",
    "AWS::SecurityHub::Insight": "1ec7254a3cf4d038",
    "AWS::SecurityHub::OrganizationConfiguration": "494d5bdaaa99a7a9",
    "AWS::SecurityHub::PolicyAssociation": "fe287d4170e40018",
    "AWS::SecurityHub::ProductSubscription": "a6a7b09a786ba544",
    "AWS::SecurityHub::SecurityControl": "062ab72de4bbcd1d",
    "AWS::SecurityHub::Standard": "a9a57a7527f5aff5",
    "AWS::SecurityLake::AwsLogSource": "672032192713ac3c",
    "AWS::SecurityLake::DataLake": "8d2f123f8e2da1c5",
    "AWS::SecurityLake::Subscriber": "3b201acecad2eb1d",
    "AWS::SecurityLake::SubscriberNotification": "6438991429ecb2db",
    "AWS::ServiceCatalog::AcceptedPortfolioShare": "aabf5162cee03316",
    "AWS::ServiceCatalog::CloudFormationProduct": "662186534ff8e643",
    "AWS::ServiceCatalog::CloudFormationProvisionedProduct": "448a377417beb2e5",
    "AWS::ServiceCatalog::LaunchNotificationConstraint": "7df0b63dbae97812",
    "AWS::ServiceCatalog::LaunchRoleConstraint": "dfc41af30527c286",
    "AWS::ServiceCatalog::LaunchTemplateConstraint": "dcbb2e3cc9935c1d",
    "AWS::ServiceCatalog::Portfolio": "2802283288dedb80",
    "AWS::ServiceCatalog::PortfolioPrincipalAssociation": "c1655e6cd9e94bc0",
    "AWS::ServiceCatalog::PortfolioProductAssociation": "39311ae1cb0b583e",
    "AWS::ServiceCatalog::PortfolioShare": "cc64bce13ce0fae6",
    "AWS::ServiceCatalog::ResourceUpdateConstraint": "7181855aed7169b4",
    "AWS::ServiceCatalog::ServiceAction": "269ecd79e230e8fa",
    "AWS::ServiceCatalog::ServiceActionAssociation": "283d0ac6cbcfde8a",
    "AWS::ServiceCatalog::StackSetConstraint": "34cef71a3b8b5ea3",
    "AWS::ServiceCatalog::TagOption": "0a7e7604f593ea6c",
    "AWS::ServiceCatalog::TagOptionAssociation": "932ff2b84208a648",
    "AWS::ServiceCatalogAppRegistry::Application": "b7ea3a99dc06bfe2",
    "AWS::ServiceCatalogAppRegistry::AttributeGroup": "2d949c9c2db95f5b",
    "AWS::ServiceCatalogAppRegistry::AttributeGroupAssociation": "5593933d7ee4cd44",
    "AWS::ServiceCatalogAppRegistry::ResourceAssociation": "948d7080333f163c",
    "AWS::ServiceDiscovery::HttpNamespace": "986cb51cac464fe8",
    "AWS::ServiceDiscovery::Instance": "b4227e1dfa14a394",
    "AWS::ServiceDiscovery::PrivateDnsNamespace": "d78a2213969ef282",
    "AWS::ServiceDiscovery::PublicDnsNamespace": "da152fa1f7dce966",
    "AWS::ServiceDiscovery::Service": "aa107587d49c4b29",
    "AWS::Shield::DRTAccess": "c17257f052b15006",
    "AWS::Shield::ProactiveEngagement": "e304603da0a03c62",
    "AWS::Shield::Protection": "6aded7784618f02c",
    "AWS::Shield::ProtectionGroup": "a95e7f5cc1499c01",
    "AWS::Signer::ProfilePermission": "602270f96863bdad",
    "AWS::Signer::SigningProfile": "f7326001695078ef",
    "AWS::StepFunctions::Activity": "b3156a89a45815e1",
    "AWS::StepFunctions::StateMachine": "f6e6ebffca5675b3",
    "AWS::StepFunctions::StateMachineAlias": "55cc66ee1f33c9f5",
    "AWS::StepFunctions::StateMachineVersion": "4467293a52255b78",
    "AWS::Synthetics::Canary": "895da8ad2bfe9dad",
    "AWS::Synthetics::Group": "ed9dcd9886d47a8d",
    "AWS::SystemsManagerSAP::Application": "8196ab023743f75e",
    "AWS::Transfer::Agreement": "ed933cf6f3e7c136",
    "AWS::Transfer::Certificate": "f7478973edec7bd3",
    "AWS::Transfer::Connector": "5ff069df52b96462",
    "AWS::Transfer::Profile": "88c7478695f7c070",
    "AWS::Transfer::Server": "90b633961fce2a5f",
    "AWS::Transfer::User": "7dbec614b03c1346",
    "AWS::Transfer::WebApp": "09ed0f7d971d7cb8",
    "AWS::Transfer::Workflow": "657766d62aa7fb4e",
    "AWS::VerifiedPermissions::IdentitySource": "b6f4f19263afee23",
    "AWS::VerifiedPermissions::Policy": "f7e75c34791cf6a5",
    "AWS::VerifiedPermissions::PolicyStore": "5883732ea6547044",
    "AWS::VerifiedPermissions::PolicyTemplate": "067128efc0e8f2eb",
    "AWS::VpcLattice::AccessLogSubscription": "fc931efc318e179a",
    "AWS::VpcLattice::AuthPolicy": "4265f5022282b0dc",
    "AWS::VpcLattice::DomainVerification": "e7469383aed1b9e4",
    "AWS::VpcLattice::Listener": "07d448be361f250e",
    "AWS::VpcLattice::ResourceConfiguration": "44271e8bd9b0bfb2",
    "AWS::VpcLattice::ResourceGateway": "22baabeee202a88c",
    "AWS::VpcLattice::ResourcePolicy": "6757614e74e0a9f9",
    "AWS::VpcLattice::Rule": "c88d86fe0a32af94",
    "AWS::VpcLattice::Service": "aca343366a1dc0f5",
    "AWS::VpcLattice::ServiceNetwork": "34e38d45feec6946",
    "AWS::VpcLattice::ServiceNetworkResourceAssociation": "15b389795ecd77f8",
    "AWS::VpcLattice::ServiceNetworkServiceAssociation": "79f2001afdfc5c64",
    "AWS::VpcLattice::ServiceNetworkVpcAssociation": "551d139b3d1105b3",
    "AWS::VpcLattice::TargetGroup": "def3cda7be3aaf2f",
    "AWS::WAF::ByteMatchSet": "bdac58da17fc8f67",
    "AWS::WAF::IPSet": "e9b5a4840b312167",
    "AWS::WAF::Rule": "2eb380e895f6c1fe",
    "AWS::WAF::SizeConstraintSet": "7b4d9b8017b0288e",
    "AWS::WAF::SqlInjectionMatchSet": "392352f8be8c6258",
    "AWS::WAF::WebACL": "347318598f8787e2",
    "AWS::WAF::XssMatchSet": "ac4c34fbea311314",
    "AWS::WAFRegional::ByteMatchSet": "994da0cf8bd3e164",
    "AWS::WAFRegional::GeoMatchSet": "dfe42573e72d6432",
    "AWS::WAFRegional::IPSet": "3b5793c5a098ae15",
    "AWS::WAFRegional::RateBasedRule": "6beb25717f354ef9",
    "AWS::WAFRegional::RegexPatternSet": "bec049612963886e",
    "AWS::WAFRegional::Rule": "ba4389c2ef956854",
    "AWS::WAFRegional::SizeConstraintSet": "13253a744f1b4519",
    "AWS::WAFRegional::SqlInjectionMatchSet": "e934a6dec5e807ed",
    "AWS::WAFRegional::WebACL": "6e6bf4ca81e9ac69",
    "AWS::WAFRegional::WebACLAssociation": "f6cb657edbe28837",
    "AWS::WAFRegional::XssMatchSet": "d06f5257461f5e67",
    "AWS::WAFv2::IPSet": "d140014308da4470",
    "AWS::WAFv2::LoggingConfiguration": "219a7415589ec0bf",
    "AWS::WAFv2::RegexPatternSet": "71e5110f182eba06",
    "AWS::WAFv2::RuleGroup": "b1d084941142148b",
    "AWS::WAFv2::WebACL": "892990086386d387",
    "AWS::WAFv2::WebACLAssociation": "d0181fa0b0d2faac",
    "AWS::Wisdom::AIAgent": "5ee8ab1c7c6da31a",
    "AWS::Wisdom::AIAgentVersion": "ebc006eddb995353",
    "AWS::Wisdom::AIPrompt": "839755a4af72ed27",
    "AWS::Wisdom::AIPromptVersion": "f1eb16962e464a28",
    "AWS::Wisdom::Assistant": "b334f5c54b6c51a1",
    "AWS::Wisdom::AssistantAssociation": "5f451a4494207cd5",
    "AWS::Wisdom::KnowledgeBase": "7a9b74f6c142ebfc",
    "AWS::Wisdom::MessageTemplate": "abd2a7d623bd398f",
    "AWS::Wisdom::MessageTemplateVersion": "85d93c94b16a675a",
    "AWS::Wisdom::QuickResponse": "f1a6189fe08948ad",
    "AWS::WorkSpaces::ConnectionAlias": "da70493ea10990d6",
    "AWS::WorkSpaces::Workspace": "97435699d74bcbe8",
    "AWS::WorkSpaces::WorkspacesPool": "321a927105979c95",
    "AWS::WorkspacesInstances::Volume": "dc5bec0e6e8edd13",
    "AWS::WorkspacesInstances::VolumeAssociation": "de659b329d22edbd",
    "AWS::WorkspacesInstances::WorkspaceInstance": "d9e9f739e378d7cd",
    "AWS::XRay::Group": "81cf1b3bfd81fc73",
    "AWS::XRay::ResourcePolicy": "1eefd10339461fe6",
    "AWS::XRay::SamplingRule": "0aa60791e2ac7d03",
    "AWS::XRay::TransactionSearchConfig": "6bf850e284a67fbb",
    "Alexa::ASK::Skill": "a71e461b8caf45a8",
    "Module": "baab0e57f109673a",
}
